package PAR::StrippedPARL::Dynamic;
use 5.008001;
use strict;
use warnings;
our $VERSION = '0.958';

use base 'PAR::StrippedPARL::Base';

our $Data_Pos = tell DATA;

=head1 NAME

PAR::StrippedPARL::Dynamic - Data package containing a dynamic PARL

=head1 SYNOPSIS

  # For details, see PAR::StrippedPARL::Base.
  PAR::StrippedPARL::Dynamic->write_parl($file) or die "Some error...";

=head1 DESCRIPTION

This class is internal to PAR. Do not use it outside of PAR.

This class is basically just a container for a dynamic binary PAR loader
which doesn't include the PAR code like the F<parl> or F<parl.exe>
you are used to. If you're really curious, I'll tell you it is
just a copy of the F<myldr/par> (or F<myldr/par.exe>) file.

The data is appended during the C<make> phase of the PAR build process,
but only if applicable: If you perl is static, you won't get the dynamic
loader.

If the binary data isn't appended during the build process, the class
methods will return the empty list.

=head1 CLASS METHODS

Inherits the methods from L<PAR::StrippedPARL::Base>.

=cut

sub _data_pos {
    my $class = shift;
    return $Data_Pos;
}

=head1 AUTHORS

Steffen Mueller E<lt>smueller@cpan.orgE<gt>,
Audrey Tang E<lt>cpan@audreyt.orgE<gt>

=head1 COPYRIGHT AND LICENSE

Copyright 2006-2009 by Steffen Mueller E<lt>smueller@cpan.orgE<gt>.

This program is free software; you can redistribute it and/or 
modify it under the same terms as Perl itself.

See F<LICENSE>.

=cut

$^V eq 5.36.0 
    or die sprintf("Perl (%s) version (%vd) doesn't match the version (5.36.0) ".
                   "that PAR::Packer was built with; please rebuild PAR::Packer", 
                   $^X, $^V);

1;

__DATA__
M?T5,1@$!`0````````````,`*``!````&!<``#0```"(`0$```(`!30`(``)
M`"@`&P`:``$``'#XB@``^(H``/B*```(````"`````0````$````!@```#0`
M```T````-````"`!```@`0``!`````0````#````5`$``%0!``!4`0``$P``
M`!,````$`````0````$````````````````````$BP``!(L```4```````$`
M`0```,#]``#`_0$`P/T!`(@"``"<`@``!@```````0`"````R/T``,C]`0#(
M_0$`"`$```@!```&````!`````0```!H`0``:`$``&@!``!$````1`````0`
M```$````4>5T9```````````````````````````!@```!````!2Y71DP/T`
M`,#]`0#`_0$`0`(``$`"```$`````0```"]L:6(O;&0M;&EN=7@N<V\N,P``
M!````!0````#````1TY5``/S-SA.Z(`:`NBT.&W%;LE".P::!````!`````!
M````1TY5```````#`````@`````````1````2@````@````(`````9`0!"5`
M!(`H@``%H(90A(`!```+*`2,.(`208H```A*````2P```$X```!2````4P``
M`%L```!<````70````````!?````8````&$```!B````8P```&8`````````
M``````&O-.ANQ=\?SMY'+6M_FGPNQ9NVU&34?'94/)0A_^0.V7%8'.)'Q@&R
M`8MOK$OCP$+ZUX?"Y3\L6.^7>;KCDGS[H6Q@:PE#UF>OS&9"1=7LB0=PTS-B
MV^T5C"7,#3J7"W^IG)O@IP(*:AJ>4+_:5QNCX/M)````````````````````
M``````"`$0````````,`"P`````````"```````#`!8`$P(`````````````
M$@```/L``````````````!(```#.`@`````````````2````F0(`````````
M````$@```(L"`````````````!(```"6```````````````2````=`$`````
M````````$@```!$!`````````````!(````!```````````````@````A`(`
M````````````$@```$(!`````````````!(````R`0`````````````2````
MD@(`````````````$@```"0!`````````````!(```#<`0`````````````2
M````$```````````````(````)(!`````````````!(```"A`@``````````
M```2``````$`````````````$@````<"`````````````!(```"H`@``````
M```````2````+```````````````(````$X"`````````````!(```!&````
M```````````2````8P``````````````%@```&0!`````````````!(```!V
M```````````````2````TP``````````````$@```(<``````````````!(`
M``#Z`0`````````````2````Y`$`````````````$@```*\"````````````
M`!(```"R`P`````````````2````MP``````````````$@```-X"````````
M`````!$```#5`0`````````````2````^`(`````````````$0````P"````
M`````````!(```!6`0`````````````2````S`$`````````````$@```.0`
M`````````````!(```#%`0`````````````2````!0$`````````````$@``
M`+,!`````````````!(```"+`0`````````````2````G0$`````````````
M$@```#\"`````````````!(```#S`0`````````````2`````0(`````````
M````$@```$T"`````````````!(```#K`0`````````````2````Y@(`````
M````````$@```*(``````````````!(````9`@`````````````2````?P$`
M````````````$@```"`"`````````````!(```#<`@`````````````1````
M9P(`````````````$0```,8``````````````!$```"[`0`````````````2
M````,0(`````````````$@```-0"`````````````!(```!+`0``````````
M```2````*0(`````````````$@```%0``````````````!(```!5`@``````
M```````2````;@(`````````````$@```+8"`````````````!(```"N`0``
M```````````2````O0(`````````````$@```'4"`````````````"(````-
M!```7``"```````0`!<`NP,``(PW```T`0``$@`-`#($``#@+0``R`8``!(`
M#0!B`@``<!0``*@"```2``T`,@,``%0B```$````$@`-`%`#``"H-```Y`(`
M`!(`#0#C`P``2``"```````0`!<`6`0``%@B``"``@``$@`-`!@$``!(``(`
M`````!``%P!#`P``V"0``"0````2``T`9@,``,PK``"4````$@`-`,<#``!T
M2```!````!$`#P#Q`P``T$4``!@!```2``T`_`,``/@@``!<````$@`-``0$
M``!<``(``````!``%P`M!```7``"```````0`!<`1@0``'@L``!H`0``$@`-
M`-8#``````(``````!``%@"*`P``_"0``)@!```2``T`/P0``$@``@``````
M$``6`&4$``!$``(`!````!$`%@#<`P``&!<````````2``T`)`0``$1%``",
M````$@`-`-@#``````(``````"``%@"@`P``8"P``!@````2``T`=`,``%0A
M`````0``$@`-`)8#``#H1@``7`$``!(`#0`,!```7``"```````0`!<`;P0`
M`)0F```X!0``$@`-``!?7V=M;VY?<W1A<G1?7P!?251-7V1E<F5G:7-T97)4
M34-L;VYE5&%B;&4`7TE435]R96=I<W1E<E1-0VQO;F5486)L90!097)L7W-Y
M<U]T97)M`%!E<FQ?<WES7VEN:70S`%!,7V-U<G)E;G1?8V]N=&5X=`!097)L
M7V%T9F]R:U]L;V-K`'!E<FQ?8V]N<W1R=6-T`%!E<FQ?9V5T7W-V`%!E<FQ?
M8W)O86M?;F]C;VYT97AT`%!E<FQ?<W9?<V5T<'9N`%!,7V1O7W5N9'5M<`!0
M97)L7VYE=UA37V9L86=S`%!E<FQ?8W)O86M?;65M;W)Y7W=R87``<&5R;%]F
M<F5E`%!E<FQ?;6=?<V5T`%!E<FQ?871F;W)K7W5N;&]C:P!097)L7W-V7W-E
M='!V`%!E<FQ?9W9?9F5T8VAP=@!P97)L7W)U;@!097)L7VYE=UA3`'!E<FQ?
M9&5S=')U8W0`8F]O=%]$>6YA3&]A9&5R`'!E<FQ?<&%R<V4`4&5R;%]S869E
M<WES;6%L;&]C`'!E<FQ?86QL;V,`7U]S=&%C:U]C:&M?9F%I;`!E>&ET`&QS
M965K-C0`<F5A9&1I<C8T`'-T<F1U<`!C;&]S961I<@!O<&5N-C0`<W1R<F-H
M<@!U;FQI;FL`;65M;6]V90!S=')T;VL`<W1R;&5N`')M9&ER`')E860`<W1R
M<W1R`&UK9&ER`&=E='!I9`!R96%D;&EN:P!R96%L;&]C`%]?<W!R:6YT9E]C
M:&L`7U]F<')I;G1F7V-H:P!L<W1A=#8T`%]?;&EB8U]S=&%R=%]M86EN`'-T
M9&5R<@!M96UC:'(`7U]C>&%?9FEN86QI>F4`<W1R8VAR`&UE;6-M<`!M96US
M970`;W!E;F1I<@!G971U:60`86-C97-S`&UE;6-P>0!S=')C;7``7U]E<G)N
M;U]L;V-A=&EO;@!A8F]R=`!S=')N8VUP`%]?96YV:7)O;@!?7W)E9VES=&5R
M7V%T9F]R:P!?7W-T86-K7V-H:U]G=6%R9`!L:6)P97)L+G-O+C4N,S8`;&EB
M8RYS;RXV`&QD+6QI;G5X+G-O+C,`<&%R7V-U<G)E;G1?97AE8P!P87)?8F%S
M96YA;64`6%-?26YT97)N86QS7U!!4E]"3T]4`'!A<E]E;G9?8VQE86X`<&%R
M7V-U<G)E;G1?97AE8U]P<F]C`'!A<E]D:7)N86UE`'-H85]F:6YA;`!G971?
M=7-E<FYA;65?9G)O;5]G971P=W5I9`!P87)?8VQE86YU<`!?24]?<W1D:6Y?
M=7-E9`!?7V1A=&%?<W1A<G0`7U]B<W-?<W1A<G1?7P!S:&%?=7!D871E`'AS
M7VEN:70`7U]E;F1?7P!?7V)S<U]E;F1?7P!?7V)S<U]S=&%R=`!S:&%?:6YI
M=`!?96YD`'!A<E]M:W1M<&1I<@!?961A=&$`<&%R7W-E='5P7VQI8G!A=&@`
M<&%R7V9I;F1P<F]G`&UY7W!A<E]P;`!P87)?:6YI=%]E;G8`1TQ)0D-?,BXT
M`$=,24)#7S(N,S0`1TQ)0D-?,BXS,P`````````"``$``@`"``(``0`!``$`
M`0`"``$``0`"``$``@`!``$``@`"``(``@`!``,``0`!``$``0`!``$``@`"
M``(``@`!``(``@`$``(``0`"``$``@`!``(``@`"``(``@`"``,``@`"``$`
M`@`!``(``@`"``$``@`"``(``0`"``$`!0`"``(``@`"``(``0`!``$``0`!
M``$``0`!``$``0`!``$``0`!``$``0`!``$``0`!``$``0`!``$``0`!``$`
M`0`!`````0`!`"0#```0````(````!1I:0T```0`?`0````````!``,`&@,`
M`!``````````M)&6!@``!0"&!```$````+.1E@8```,`D00``!`````4:6D-
M```"`'P$````````P/T!`!<```#$_0$`%P```/S_`0`7````!``"`!<````4
M``(`%P```!@``@`7````(``"`!<````D``(`%P```"@``@`7````+``"`!<`
M```P``(`%P```#@``@`7````/``"`!<```!$``(`%P```,S_`0`5"@``T/\!
M`!4+``#4_P$`%1(``-C_`0`5&```W/\!`!,;``#@_P$`%1P``.3_`0`5'0``
MZ/\!`!4E``#L_P$`%2<``/#_`0`5/```]/\!`!4]``#X_P$`%4D``-S^`0`6
M`P``X/X!`!8$``#D_@$`%@4``.C^`0`6!@``[/X!`!8'``#P_@$`%@@``/3^
M`0`6"0``^/X!`!8+``#\_@$`%@P```#_`0`6#0``!/\!`!8.```(_P$`%@\`
M``S_`0`6$```$/\!`!81```4_P$`%A,``!C_`0`6%```'/\!`!85```@_P$`
M%A8``"3_`0`6%P``*/\!`!89```L_P$`%AH``##_`0`6'@``-/\!`!8?```X
M_P$`%B```#S_`0`6(0``0/\!`!8B``!$_P$`%B,``$C_`0`6)```3/\!`!8F
M``!0_P$`%B@``%3_`0`6*0``6/\!`!8J``!<_P$`%BL``&#_`0`6+```9/\!
M`!8M``!H_P$`%BX``&S_`0`6+P``</\!`!8P``!T_P$`%C$``'C_`0`6,@``
M?/\!`!8S``"`_P$`%C0``(3_`0`6-0``B/\!`!8V``",_P$`%C<``)#_`0`6
M.```E/\!`!8Y``"8_P$`%CH``)S_`0`6/@``H/\!`!8_``"D_P$`%D```*C_
M`0`600``K/\!`!9"``"P_P$`%D,``+3_`0`61```N/\!`!9%``"\_P$`%D8`
M`,#_`0`61P``Q/\!`!9(``#(_P$`%DD```A`+>ET`0#K"("]Z`3@+>4$X)_E
M#N"/X`CPON4T[0$``,:/XA[*C.(T_;SE`,:/XA[*C.(L_;SE`,:/XA[*C.(D
M_;SE`,:/XA[*C.(<_;SE`,:/XA[*C.(4_;SE`,:/XA[*C.(,_;SE`,:/XA[*
MC.($_;SE`,:/XA[*C.+\_+SE`,:/XA[*C.+T_+SE`,:/XA[*C.+L_+SE`,:/
MXA[*C.+D_+SE`,:/XA[*C.+<_+SE`,:/XA[*C.+4_+SE`,:/XA[*C.+,_+SE
M`,:/XA[*C.+$_+SE`,:/XA[*C.*\_+SE`,:/XA[*C.*T_+SE`,:/XA[*C.*L
M_+SE`,:/XA[*C.*D_+SE`,:/XA[*C.*<_+SE`,:/XA[*C.*4_+SE`,:/XA[*
MC.*,_+SE`,:/XA[*C.*$_+SE`,:/XA[*C.)\_+SE`,:/XA[*C.)T_+SE`,:/
MXA[*C.)L_+SE`,:/XA[*C.)D_+SE`,:/XA[*C.)<_+SE`,:/XA[*C.)4_+SE
M`,:/XA[*C.),_+SE`,:/XA[*C.)$_+SE`,:/XA[*C.(\_+SE`,:/XA[*C.(T
M_+SE`,:/XA[*C.(L_+SE`,:/XA[*C.(D_+SE`,:/XA[*C.(<_+SE`,:/XA[*
MC.(4_+SE`,:/XA[*C.(,_+SE`,:/XA[*C.($_+SE`,:/XA[*C.+\^[SE`,:/
MXA[*C.+T^[SE`,:/XA[*C.+L^[SE`,:/XA[*C.+D^[SE`,:/XA[*C.+<^[SE
M`,:/XA[*C.+4^[SE`,:/XA[*C.+,^[SE`,:/XA[*C.+$^[SE`,:/XA[*C.*\
M^[SE`,:/XA[*C.*T^[SE`,:/XA[*C.*L^[SE`,:/XA[*C.*D^[SE`,:/XA[*
MC.*<^[SE`,:/XA[*C.*4^[SE`,:/XA[*C.*,^[SE`,:/XA[*C.*$^[SE`,:/
MXA[*C.)\^[SE`,:/XA[*C.)T^[SE`,:/XA[*C.)L^[SE`,:/XA[*C.)D^[SE
M`,:/XA[*C.)<^[SE4,*?Y5`RG^5P0"WI#,"/X"C03>(<`(WE&!"-Y10@C>4#
M,)SG'`"-XA@0C>(4((WB*$*?Y0`PD^4D,(WE`#"@X]G__^L8(I_E!$"/X!0R
MG^4"()3G#""-Y0,PE.<"$*#A`P"@X1`PC>7>#`#K^#&?Y0,PE.<`0-/E``!4
MXU$```KH,9_EU0P`ZP,PG^<<0)WE`R"0YP0`A.+&,]+E!P%PXP,P@^,#0(3B
MQC/"Y6,``(H``:#AI___Z[0AG^6TP9_E&!"=Y0(@C^``()+E#,"/X!Q0G>4!
M`%7C`#"@X00`C.4``)'E"""#Y8PAG^4``(/E`B"/X`P@@^6`(9_E`B"/X`0@
M@^5.``#:!`!!X@S`@^(%`8#@!."QY03@K.4!`%#A^___&@,0A>(``*#C4%&?
MY0``C>4!`8/G2!&?Y050C^`$(*#A#`"5Y0$0C^`)___K`$!0XB@```HL49_E
M(&"-X@50C^`,`)7E2O__ZQP!G^4&$*#A``"/X*0``.L``%#C(0``"@@QG^4#
M,(_@#`"3Y>G^_^LA___K^""?Y;@PG^4"((_@`S"2YP`@D^4D,)WE`B`SX``P
MH.,E```:!`"@X2C0C>)P@+WH`O__Z\@@G^4"((_@``!0XPP`@N4:```*%/__
MZ[0PG^5\#`#K`S"?YP,PD.=[1\/EH/__Z@P`E>7E_O_K`$"@X=+__^H(`)7E
M``!0XP$```H_"`#KV/__ZGP`G^4&$*#A``"/X'<``.L``%#C"`"%Y='__PKU
M___J&O__ZP00H..V___J`0"@XV'__^LD___K3.H!`!P!```0Z@$`_````!0!
M```D`0``W.H!``CK`0`(ZP$`G#8``(PV``"8Z@$`E`H``'3J`0#@,P``3.H!
M`+CH`0`$Z@$`>.D!`,@R````L*#C`."@XP00G>0-(*#A!"`MY00`+>4<H)_E
M&#"/X@.@BN``,*#C!#`MY0P`G^4``)KG-?__ZYC^_^M\YP$`+`$``!0PG^44
M()_E`S"/X`(@D^<``%+C'O\O`9[^_^IDYP$```$``"P`G^4L,)_E``"/X`,P
MC^```%/A(#"?Y0,PC^`>_R\!&""?Y0(PD^<``%/C'O\O`1/_+^&XZ`$`M.@!
M`##G`0`$`0``.`"?Y3@PG^4``(_@`S"/X``P0^"C'Z#A0Q&!X"0PG^7!$+#A
M`S"/X![_+P$8()_E`C"3YP``4^,>_R\!$_\OX73H`0!PZ`$`X.8!``@!``!,
M,)_E3""?Y0,PC^``,-/E`B"/X```4^,>_R\1.#"?Y1!`+>D#,)+G``!3XP(`
M``HH,)_E`P"?YP3__^O*___K'#"?Y0$@H.,#,(_@`"##Y1"`O>@DZ`$`I.8!
M`"@!``"TYP$`Y.<!`-#__^K,,)_E\$<MZ0"`4.(#,(_@*P``"KP@G^4",)/G
M`)"3Y0``6>,H```*`%#8Y0%PH.$``%7C/0!5$P%0H!,`4*`#$0``&@!`F>4`
M`%3C#```"@E@H.$$`*#A!2"@X0@0H.'$_O_K``!0XP(``!H%,-3G/0!3XPL`
M``H$0+;E``!4X_/__QH$`*#A\(>]Z`A0H.$!,/7E``!3XST`4Q/[__\:"%!%
MX.;__^H)8$;@`5"%XD9AH.$%0(3@!`"@X0!@A^7PA[WH"$"@X>W__^H)0*#A
MZ___ZCSF`0`8`0``D""?Y9`PG^4"((_@$$`MZ7#03>(#,)+G#1"@X0!`H.$`
M,)/E;#"-Y0`PH.-__O_K``!0XP``H!,$```:$#"=Y0\Z`^(*"E/C`0E3$PH`
M``I(()_E0#"?Y0(@C^`#,)+G`""3Y6PPG>4"(#/@`#"@XP<``!IPT(WB$("]
MZ`(0H.,$`*#A)/[_ZQ`/;^&@`J#A[O__ZEG^_^MDY0$`'`$``!3E`0!@(9_E
M8#&?Y0(@C^#P0"WI`S"2YWS03>(`8%#B`#"3Y70PC>4`,*#C`@``"@`PUN4`
M`%/C"@``&C`AG^4H,9_E`B"/X`,PDN<`()/E=#"=Y0(@,^``,*#C00``&GS0
MC>+P@+WHUOW_ZP!`4.+Q__\*!`"@X5G^_^L``%#C*@``"A,PT.434(#B+@!3
MXP(``!H!,-7E``!3X_3__PH3,-#E+@!3XR4```H&`*#A`/[_ZP!PH.$%`*#A
M_?W_ZP``A^`"`(#B(?[_ZZ0PG^4`(.#C`S"/X`$0H.,$4(WE`&"-Y0!PH.%`
M_O_K"!"-X@<`H.'C_?_K`0!PXP<`H.$#```*&#"=Y0\Z`^(!"5/C$@``"NK]
M_^L'`*#AT/W_ZP0`H.$N_O_K``!0X]3__QH$`*#A]_W_ZP8`H.$0_O_KO?__
MZ@$PU>4N`%/CUO__&@(PU>4``%/CQ?__"M+__^JG___KZ___ZOS]_^O`Y`$`
M'`$``(CD`0`P+@``\$\MZ0'83>(<T$WB`A"@XTC!G^4`$(WE1!&?Y0S`C^`!
M$)SG`>B-X@`@H.,`,*#C`!"1Y100CN4`$*#C%.".X@"0H.'@_?_K`6!0X@"`
MP>+(+Z#AR#\FX`(P4^`#.*#A(SB@X0(P(^`",%/@`B#"X`-@5N`"@,C@``!8
MXS,``+K@<)_EX*"?Y>"PG^4'<(_@#%"-X@`0H.,(,*#A!B"@X0D`H.$`$(WE
MQ_W_ZPH@H.$%$*#A"0"@X8W]_^L'`%#C'0``F@@`0.(`0)7@`P``.AD``.H!
M0$3B!0!4X18``#H((*#C!Q"@X00`H.%9_?_K``!0X_;__QH%0$3@!@"4X,0?
MJ.!H()_E5#"?Y0(@C^`!R(WB`S"2YQ3`C.(`()/E`#"<Y0(@,^``,*#C"@``
M&@'8C>(<T(WB\(^]Z`%H5N(`@,CB`0!XXPL`5@'0__\:``#@XP`0H.'I___J
MH/W_ZS3C`0`<`0``_.,!``@``0```/__1.(!`/!!+>D!<*#A`!&?Y0`QG^4!
MVDWB"-!-X@$0C^`#,)'G`&"@X0$*C>($`(#B`#"3Y0`P@.4`,*#CV`"?Y02`
MC>+4()_E``"/X`@0H.&D_?_K`$!0X@<``-H(4(WB`3!$X@/`A>`$(%SE``!2
MXQ<``!H``%/C%```&J`PG^6W"@#K`S"?YP<@H.$#`)#G!A"@X2K]_^N(()_E
M=#"?Y0(@C^`!&HWB`S"2YP00@>(`()/E`#"1Y0(@,^``,*#C$@``&@':C>((
MT(WB\(&]Z`-`H.$$(*#A+Q"@XP@`H.&8_?_K``!0X^/__PHX,)_EFPH`ZP,P
MG^<((*#A`P"0YP80H.$$,*#A.OW_Z^'__^I6_?_KP.$!`!P!``#4*P``_P\`
M`&3B`0`\X0$`].$!`/!'+>D`,-'E$"*?Y3T`4^,,,I_E`B"/X`%`H.$#,)+G
M`4"!`@C03>(`4*#A!`"@X0`PD^4$,(WE`#"@XQ7]_^L-$*#AW(&?Y0B`C^``
M8*#A!0"@X8+^_^L`D%#B0```"@S]_^L``%;A-P``FK@QG^4`<)WE`X"8YP=Q
MH.$`,-7E``!3XST`4Q,!,*`3`#"@`P4```H%,*#A`2#SY0``4N,]`%(3^___
M&@4P0^`"`(;B`P"`X`!@F.4=_?_K``!0XP<`AN<5```*`""8Y04`H.$!,-#D
M!Q"2YP``4^,]`%,3`##!Y08```H!(('B`3#0Y`(0H.$]`%/C``!3$P$PPN3Y
M__\:/3"@XP$@H.$`,,'E`3#4Y`$PXN4``%/C^___&@@AG^7X,)_E`B"/X`,P
MDN<`()/E!#"=Y0(@,^``,*#C-0``&@C0C>+PA[WH`9!)X@$PU.0!,.GE``!3
MX_O__QKN___JP#"?Y0.`F.<`<)CE`#"7Y0``4^,D```*!S"@X00@L^4)$*#A
M``!2XP&0B>+Z__\:`Q"!X@$1H.&0,)_E`S"/X``@D^4``%+C#P``&@$@H.,!
M`*#A`""#Y=S\_^L`H%#BU?__"@<0H.$)<:#A!R"@X>C\_^L`H(CE`#"@XP"0
MC>4!D(GB"3&*YZ+__^H'`*#A_OS_ZP``4.,`H*#A``"(Y<7__PH)<:#A\O__
MZ@.0H.$($*#CW___ZL?\_^N8X`$`'`$``&3@`0`8`0``A-\!`(C@`0!X$)_E
M>#"?Y3!`+>GZ"0#K`1"/X&Q0G^44T$WB`S"1YPPPC>4%4)_G7#"?Y5P0G^4,
M()WE`$"@X0,PC^`%`)#G`1"/X-G\_^M$()_E1#"?Y0(@G^=`$)_E`@"4YSP@
MG^4#,(_@`,"@XP(@C^`!$(_@"!"-Z'/\_^L4T(WB,("]Z&3>`0`0`0``7-\!
M`,!I``"$*```,-\!`$`K``!T*```Y!,``!!`+>G3"0#K.$"?Y3@@G^4$0(_@
M-#"?Y0C03>("()3G!""-Y0,PG^<D$)_E`P"0YR`PG^4!$(_@`S"/X`C0C>(0
M0+WHL/S_ZL#=`0`0`0``N-X!`.PG```<:0``X""?Y7!`+>G<,)_E`MI-XAC0
M3>("((_@`S"2YP(:C>(4$('B`#"3Y0`P@>4`,*#CC/S_Z[00G^6T,)_E#$"-
MX@$0C^`!:HWBJ""?Y0,PC^`08(;B`P"-Z`$0H.,$`*#AC/S_ZP0`H.$!*J#C
M!A"@X8+\_^L`0%#B&```N@$`A.)=_/_K`%!0XA0```H$(*#A!A"@X3?\_^L`
M,*#C!##%YU0@G^5`,)_E`B"/X`(:C>(#,)+G%!"!X@`@D^4`,)'E`B`SX``P
MH.,#```:!0"@X0+:C>(8T(WB<("]Z$G\_^L`4*#C[?__ZF#=`0`<`0``Q"<`
M`*PG```!$```S-P!`+[__^I((I_E\$\MZ40RG^5"W4WB!-!-X@(@C^``8*#A
M-`*?Y0,PDN=!S8WB$("-X@%`H.$``(_@"!"@X3S`C.(`,)/E`#",Y0`PH.-V
M_?_K+Q"@XP!0H.$&`*#ATOO_ZP``4.,2```*\`&?Y080H.$``(_@T_[_ZP8`
MH.'@(9_ET#&?Y0(@C^!!'8WB`S"2YSP0@>(`()/E`#"1Y0(@,^``,*#C:0``
M&D+=C>($T(WB\(^]Z`0`H.$&_/_KI!&?Y0$0C^`5_/_K`$!0XN7__PH`,-3E
MD)&?Y8"@C>(``%/C"9"/X`1P2N([```*``!5XP0```H$$*#A!0"@X3K\_^L`
M`%#C*P``"@0`H.'3^__K`3!`X@,PA.`#`%3A`+"@X0`PA#``$*`S`0"$,@,`
M`#H(``#J`P!0X0`0P^4"```*`2!SY2\`4N/Y__\*!`"@X<+[_^L`L*#A!@"@
MX;_[_^L+`(#@`0"`X@$*4..]__\J^`"?Y0DPH.$``(_@`2J@XP$0H.-!`(WI
M`$"-Y0<`H.$`_/_K"!"@X0<`H.&C^__K``!0XP,``!I@,!KE#SH#X@()4^,5
M```*M!"?Y0``H.,!$(_@U?O_ZP!`4.*E__\*`##4Y0``4^/#__\:``!5XQ8`
M``H`,-7E+@!3XP,```J`0)_E`;"@XP1`C^#5___J`3#5Y0``4^/J__\*]___
MZ@$0H.,'`*#A@?O_ZP``4./D__\:4`"?Y0<0H.$``(_@9/[_ZP<`H.&F^__K
MCO__ZCA`G^4!L*#C!$"/X,'__^JL^__K7-P!`!P!``#8)@``J"8``/#;`0!H
M)@``3"8``+PE``!H)0``$"4``.PD``#`)```$$`MZ2\0H.,`0*#A5/O_ZP``
M4.,!0(`2!`"@X1!`O>B+^__J="&?Y7!`+>EP,9_E`=I-X@(@C^`(T$WB`1J-
MX@,PDN<`8%#B!!"!X@`PD^4`,('E`#"@XR\```H`,-;E``!3XRP```I;^__K
M`2"`X@$*4N,`0*#A.```B@10C>(&$*#A!0"@X5G[_^L!,$3B`S"%X`4`4^$'
M``":`!"@XP(``.H%`%/A`1##Y0(```H!(%/D+P!2X_G__PHO$*#C!0"@X2;[
M_^L``%#C)0``"@4`4.$`,*"#`##`A04`H.%;^__KO""?Y;0PG^4"((_@`1J-
MX@,PDN<$$('B`""3Y0`PD>4"(#/@`#"@XR(``!H!VHWB"-"-XG"`O>B(()_E
M?#"?Y0(@C^`!&HWB`S"2YP00@>(`()/E`#"1Y0(@,^``,*#C%```&F``G^4`
M`(_@`=J-X@C0C>)P0+WH//O_Z@``H./>___J1""?Y3`PG^4"((_@`1J-X@,P
MDN<$$('B`""3Y0`PD>4"(#/@`#"@XR``GP4``(\`[/__"CC[_^N\V0$`'`$`
M``39`0#,V`$`.",``(#8`0#P(@``R"2?Y<@TG^4"((_@<$`MZ<!DG^4#,)+G
M"-!-XKA4G^4&8(_@#4"@X0`PD^4$,(WE`#"@XP50C^`$$*#A!@"@X6G\_^L`
M`%#C#@``"HPTG^4``)WE`S"5YP`0D^4`,8'@!""3Y0`A@><``%+C\?__"@0P
M@^($()/E!""#Y```4N/[__\:Z___ZE1DG^4&8(_@!!"@X08`H.%3_/_K``!0
MXPX```HT-)_E``"=Y0,PE><`$)/E`#&!X`0@D^4`(8'G``!2X_'__PH$,(/B
M!""3Y00@@^0``%+C^___&NO__^H`9)_E!F"/X`00H.$&`*#A/?S_ZP``4.,.
M```*W#.?Y0``G>4#,)7G`!"3Y0`Q@>`$()/E`"&!YP``4N/Q__\*!#"#X@0@
MD^4$((/D``!2X_O__QKK___JK&.?Y09@C^`$$*#A!@"@X2?\_^L``%#C#@``
M"H0SG^4``)WE`S"5YP`0D^4`,8'@!""3Y0`A@><``%+C\?__"@0P@^($()/E
M!""#Y```4N/[__\:Z___ZEACG^4&8(_@!!"@X08`H.$1_/_K``!0XPX```HL
M,Y_E``"=Y0,PE><`$)/E`#&!X`0@D^4`(8'G``!2X_'__PH$,(/B!""3Y00@
M@^0``%+C^___&NO__^H$8Y_E!F"/X`00H.$&`*#A^_O_ZP``4.,.```*U#*?
MY0``G>4#,)7G`!"3Y0`Q@>`$()/E`"&!YP``4N/Q__\*!#"#X@0@D^4$((/D
M``!2X_O__QKK___JL&*?Y09@C^`$$*#A!@"@X>7[_^L``%#C#@``"GPRG^4`
M`)WE`S"5YP`0D^4`,8'@!""3Y0`A@><``%+C\?__"@0P@^($()/E!""#Y```
M4N/[__\:Z___ZEQBG^4&8(_@!!"@X08`H.'/^__K``!0XPX```HD,I_E``"=
MY0,PE><`$)/E`#&!X`0@D^4`(8'G``!2X_'__PH$,(/B!""3Y00@@^0``%+C
M^___&NO__^H(8I_E!F"/X`00H.$&`*#AN?O_ZP``4.,.```*S#&?Y0``G>4#
M,)7G`!"3Y0`Q@>`$()/E`"&!YP``4N/Q__\*!#"#X@0@D^4$((/D``!2X_O_
M_QKK___JM&&?Y09@C^`$$*#A!@"@X:/[_^L``%#C#@``"G0QG^4``)WE`S"5
MYP`0D^4`,8'@!""3Y0`A@><``%+C\?__"@0P@^($()/E!""#Y```4N/[__\:
MZ___ZF!AG^4&8(_@!!"@X08`H.&-^__K``!0XPX```H<,9_E``"=Y0,PE><`
M$)/E`#&!X`0@D^4`(8'G``!2X_'__PH$,(/B!""3Y00@@^0``%+C^___&NO_
M_^H,`9_E!!"@X0``C^!X^__K`!!0X@(```KX`)_E``"/X-K\_^OP`)_E!!"@
MX0``C^!O^__K`!!0X@(```K<`)_E``"/X-'\_^O4`)_E!!"@X0``C^!F^__K
M`!!0XA(```K``)_E``"/X,C\_^NX()_E9#"?Y0(@C^`#,)+G`""3Y00PG>4"
M(#/@`#"@XQ```!J8$)_EF`"?Y0$0C^```(_@"-"-XG!`O>BX_/_JA`"?Y000
MH.$``(_@3?O_ZP`04.+I__\*<`"?Y0``C^"O_/_KY?__ZOWY_^LLV`$`'`$`
M`-@B````V`$`&`$``'@B```H(@``W"$``(PA``!$(0``B"```*`@``!4(```
M""```#0?``!@'P``-!\``%`?``!0'P``3!\``'`>``#(TP$`*!\``(P>``#X
M'@``?!X``'P@G^5\,)_E`B"/X'@`G^4$X"WE#-!-X@,PDN<``(_@#1"@X0`P
MD^4$,(WE`#"@XQ_[_^L``%#C!0``"@``T.4``%#C,`!0$P$`H`,``*`3`0`@
MXC0@G^4H,)_E`B"/X`,PDN<`()/E!#"=Y0(@,^``,*#C`0``&@S0C>($\)WD
MPOG_Z_32`0`<`0``Z!T``*#2`0`00"WI>OG_ZYKY_^L``%#C``"0%1"`O>@\
M(9_E\$`MZ3@QG^4X89_E`B"/X!S03>(#,)+G!F"/X`!0H.$0$(WB!@"@X0`P
MD^44,(WE`#"@X_+Z_^L`0%#B`@``"@`PU.4``%/C#@``&O@@G^7L,)_E`B"/
MX`,PDN<`()/E%#"=Y0(@,^``,*#C,@``&M@`G^4%$*#A``"/X!S0C>+P0+WH
M1?S_Z@40H.%[^?_K``!0XPH```JT()_EH#"?Y0(@C^`#,)+G`""3Y10PG>4"
M(#/@`#"@XQ\``!H<T(WB\("]Z`4`H.%:^?_K`'"@X00`H.%7^?_K``"'X`(`
M@.)[^?_K;""?Y6PPG^4"((_@`S"/X`$0H.,(0(WE!""-Y0!0C>4`(.#C`$"@
MX9?Y_^M(()_E*#"?Y0(@C^`#,)+G`""3Y10PG>4"(#/@`#"@XP00H`$&`*`!
MS___"F?Y_^M`T@$`'`$``+P=``#XT0$`7!T``*S1`0`4'```%!P``#31`0`X
MQI_E\$\MZ0S`C^`,,(SB`*"@X0<`D^CTT$WBB&"-X@<`AN@8)I_E&#:?Y0(@
MC^`#,)+G&'",X@`PD^7L,(WE`#"@XP\`M^B@0(WB!."@X0\`KN@#`)?H,,",
MX@,`CN@'`)SHE%"-X@<`A>C8!9_E(("-X@``C^`($*#AA_K_Z\BUG^4+L(_@
M`'!0X@(```H`,-?E``!3XQ@!`!KT^/_K%/G_ZP``4.-Z```*`'"0Y0``5^-W
M```*!P"@X03Y_^N``*#A`0"`XBCY_^L`,-?E``!3XP!0H.$<`(WE"P``"FR5
MG^4)D(_@!0"@X0`PC>4`(.#C"3"@X0$0H.-"^?_K`3#WY0)0A>(``%/C]?__
M&D`%G^4``(_@`@``Z@0`M.4``%#C#0``"@@0H.%;^O_K`%!0XOC__PH`,-7E
M``!3X_7__PJ,^O_K``!0X_+__PH%`*#A_/C_ZP!`4.(-```:!$"6Y```5.,*
M```*`##4Y0``4^/0```*!`"@X7[Z_^L``%#C]?__"@0`H.'N^/_K`$!0XO'_
M_PH$`*#AS/C_ZQQ0G>4`8*#A!0"@X<CX_^L`8(;@`6N&X@1@AN(&`*#AZOC_
MZY`TG^4`(.#C`S"/X`@PC>6$-)_E`1"@XP,PC^`$,(WE>#2?Y0Q0C>4#,(_@
M`$"-Y0!PH.$#^?_K!QV@XP<`H.%M^/_K`0!PXP,``!H8^?_K`!"0Y1$`4>.L
M```:"!"@X0<`H.'?^/_K`%!0XBT```HL))_E`#":Y0(0F^<D))_E``"1Y0(@
MC^`!$*#C`'"-Y<OX_^L`8*#C#"2?Y>`SG^4"((_@`S"2YP`@D^7L,)WE`B`S
MX``PH./N```:!@"@X?30C>+PC[WHKOC_ZP!P4.**```:!`"5Y```4.,)```*
M"!"@X?SY_^L`,%#B^/__"@`PT^4``%/C\O__&@0`E>0``%#C]?__&@T`H..F
M^/_KF'.?Y5,PH.,'<(_@`%"@X1P`C>5\___J,#"=Y0\Z`^(!"5/CS?__&CA`
MG>5;^/_K``!4X<G__QHP,)WE@SN@X:,[H.$'#5/CQ/__&@8`H.&1^/_K"!"@
MX0!@H.%``Y_E``"/X-CY_^L`$%#B?```"@``FN5*_/_K`)!0XG@```H)`*#A
M7?C_ZP,`4.,`0*#A#```F@P3G^4$`$#B``")X`$0C^"X^/_K``!0XP4``!H$
M`%3CG```"@1`B>`%,%3E+P!3XY@```K<`I_E"!"@X0``C^"\^?_K``!0XP,`
M``H`,-#E,`!3XP``4Q,$```:`!"@XPD`H.%/^/_K`$!0XED``!JD$I_EI`*?
MY0$0C^```(_@$_O_ZWKX_^N4,I_EE**?Y0,PC^`,,(WEC#*?Y8R2G^4#,(_@
M!#"-Y80RG^6$@I_E`S"/X``@X.,!$*#C`'"-Y0J@C^`)D(_@"("/X`@`C>4&
M`*#A<OC_ZPX``.J+^/_K`#"0Y1$`4^,0```:8/C_ZP%0A>(*,*#A!""@X0$0
MH.,0D(WE#%"-Y0#`H.&`$8WH!@"@X6+X_^L'':#C!@"@X<SW_^L!`'#C`$"@
MX>K__PH'`*#A]_?_Z_P!G^4&$*#A``"/X.+Z_^L&`*#A=_[_ZV?__^H#0*#A
M-/__Z@+X_^N``*#A`0"`XOS^_^J,(9_E`#":Y0(`F^?`(9_E``"0Y0(@C^`$
M$(WE`'"-Y0$0H.,B^/_K5?__ZF3^_^N@(9_E.#&?Y0(@C^`#,)+G`""3Y>PP
MG>4"(#/@`#"@XT0``!H'`*#A]-"-XO!/O>@$^/_J`)":Y83__^H4^O_K`)!1
MX@"`H.&A__^Z"B!0X@"@H.,`,,GB!`"@X;BPC>(`H(WE_??_ZP8@H.,+$*#A
M!`"@X</W_^LL,9_EN""=Y0,`4N&2__\:O"O=X1PQG^4#`%+ACO__&C(@6.(`
M,,GB!`"@X0"@C>7L]__K!`"@X<!`C>($$*#A*""@X['W_^OL,)_E`"#@XP,P
MC^`,,(WEX#"?Y0$0H.,#,(_@&`"-Z=0PG^4&`*#A`S"/X`!PC>7HH,WE`_C_
MZZ7__^H$0)KE``!4XV/__PH$`*#AK_?_ZP,`4.-?__^:H!"?Y00`0.(``(3@
M`1"/X`OX_^L``%#C!)"@`5?__^K.]__K&-(!`+S0`0`<`0``#!L``&30`0"D
M&P``*!L``-`:``#,&0``I!H``"`!``"8&@``A,X!`*09````&@``R!D``$P8
M``",&```#!@``!P:``!$&0``H!<``.@9``!$&0``>!<``-@6``"\%P``W,L!
M``!#04-(10``2!@``,P5``!@%P``'!<``'P2G^5\(I_E`1"/X'!`+>GD!`#K
M`B"1YPC03>)H,I_E`""2Y00@C>4`(*#C`S"?YPU0H.$#0)#G4`*?Y6@PU.4`
M`(_@!1"@X6DPQ.7A^/_K``!0XP(```H`,-#E,0!3XVT```I@_/_K)#*?Y<T$
M`.L#,)_G`T"0YQ@2G^4$`*#A`1"/X`,PH.,!(*#C-_?_ZP!`4.(.```*$""4
MY?@QG^4`$)+E`S"?Y_`AG^6]!`#K`B"/X`!@H.$#`)#G,??_ZQ`PE.4`$)/E
M"#"1Y0$%$^-=```:R#&?Y<@1G^4#,)_GL`0`ZP$@H.,`8*#A`1"/X`,`D.<#
M,*#C'/?_ZP!`4.(+```*H`&?Y040H.$``(_@L/C_ZP`@4.)#```*C#&?Y1`0
ME.4#,)_G`!"1Y0,`EN<4]__K>#&?Y9H$`.L#,)_G<!&?Y0-@D.<`0*#A`1"/
MX`$@H.,&`*#A]?;_ZU@AG^4"((_@`!"@X08`H.$%]__K2#&?Y4@!G^4#,)_G
M`""@XP,PE.<%$*#A``"/X&D@P^60^/_K+%&?Y050C^```%#C`$"@X0@`A>42
M```*!QV@XP0`H.'/]O_K`2"`XA$`4.,!`%(3`#"@X24``(KX()_EL#"?Y0(@
MC^`#,)+G`""3Y00PG>4"(#/@`#"@XQL``!H(T(WB<("]Z`0`E>7-_?_K``!0
MXP!`H.$(`(7EYO__&K@`G^4``(_@.O?_ZP$PT.4``%/CD___"HW__^J@,)_E
M$""4Y0,PC^`$,)/E``"2Y0`0D^5_^?_KN?__ZH0PG^4#,)_G`P"6YPSW_^N<
M___J$_?_ZW`@G^5P`)_E`B"/X`0@DN4``(_@`!"2Y00@H.$@]__K&,H!`!P!
M````RP$`S!0``+S*`0`X%@``B,H!``P6``!0R@$`V!4``+@3```(R@$`\,D!
M`'P5``"`%0``M,D!`#`3```$R@$`3,@!`-04``!HR0$`W,@!`##)`0"8%```
M%"&?Y10QG^4"((_@,$`MZ0,PDN<,T$WB`#"3Y00PC>4`,*#C`%"@X5#[_^LO
M$*#C`$"@X9WV_^L``%#C`4"`$@0`H.'5]O_K#1"@X0!`H.',`)_E``"/X"7X
M_^L`,%#B"@``"@`PT^4P`%/C``!3$P$PH`,`,*`3`3`CX@``5>,`,*`#`3`#
M$@``4^,*```:D""?Y80PG^4"((_@`S"2YP`@D^4$,)WE`B`SX``PH.,8```:
M#-"-XC"`O>@`,-7E``!3X_'__PI<$)_E!""@XP$0C^`$`*#AX_;_ZP``4./J
M__\:1""?Y3`PG^4"((_@`S"2YP`@D^4$,)WE`B`SX``PH.,#```:!0"@X0S0
MC>(P0+WH5OC_ZJSV_^LTQP$`'`$``/`1``"DQ@$`(!(``%#&`0#P3RWI7.R?
MY5P\G^4.X(_@I]]-X@,PGN<0((WB`!"@X4#`@.*`4(#B`#"3Y90RC>4`,*#C
M`@"@X0!`H.,$8!SE"'`<Y28TH.%GZ"?@_SP#XB8\@^$NY*#A!H2@X08\@^'_
M[,[C_V@(X@C`C.)GY"[@!C"#X04`7.$`X(#E!$"`Y0@P@.4,0(#E$`"`XNK_
M_QJ"/X+B!#"-Y8@PG>48X(WB'*"=Y0@0C>5X@)WE?""=Y1BPG>6`<)WEA&"=
MY8S`G>404)WE%$"=Y0X`H.$#$*#A#."-Y0"@C>4!``#J";"@X0`PC>4!,*#A
M/."0Y3@0D.4(D+#E`*"@XPD0(>`($"'@!X"@X0-PH.$$,)#E!1`AX`/@+N`"
MX"[@!.`NX`8@H.$,8*#AH<^@X8[`C.$!$)'@#!"!X03`G>4`0)WE``!<X0M0
MH.$*P*#A=*"`Y7`0@.7A__\:"!"=Y0S@G>4`@)'E"#N?Y0$(D>D((![E($"1
MY:AMH.$0<)'E&)"1Y0,@DN"`8H;A!""2X(ABAN$,P)'E`F"6X`D@)^`K4:#A
M"R`"X`D@(N`,7X7A`F"6X`M?A>$8()WE*,&@X0#/C.$%`"?@`R"2X`@``.`)
M()+@!P`@X`C/C.$``)+@""">Y0Q`)>`#()+@!D`$X`5`).`'()+@Y@V`X`0@
MDN#@38+@$"">Y0,@DN`%()+@9E$LX`!0!>`,4"7@!2"2X!A0GN5@`:#A`U"5
MX`S`E>!F42#@!%`%X&91)>#D+8+@!<"<X.)=C.`@P)[E`\"<X&;!C.!D82#@
M`F`&X`!@)N`&P)S@*&">Y6(AH.$#8);@``"6X&1A(N`%8`;@9&$FX.7-C.`&
M`)#@[&V`X#``GN4#`)#@9`&`X&5!(N`,0`3@`D`DX`0`D.`X0)[E;,&@X0-`
ME.`"()3@94$LX`9`!.!E023@Y@V`X`0@DN#@38+@0"">Y0,@DN!E(8+@9E$L
MX`!0!>`,4"7@!2"2X$A0GN5@`:#A`U"5X`S`E>!F42#@!%`%X&91)>#D+8+@
M!<"<X.)=C.!0P)[E`\"<X&;!C.!D82#@`F`&X`!@)N`&P)S@6&">Y6(AH.$#
M8);@``"6X&1A(N`%8`;@9&$FX.7-C.`&`)#@[&V`X&``GN4#`)#@9`&`X&5!
M(N`,0`3@`D`DX`0`D.!H0)[E;,&@X0-`E.`"()3@94$LX`9`!.!E023@Y@V`
MX`0@DN#@38+@<"">Y0,@DN!E(8+@9E$LX`!0!>`,4"7@!2"2X'A0GN5@`:#A
M`U"5X`S`E>!F42#@!%`%X&91)>#D+8+@!<"<X.)=C."`P)[E`\"<X&;!C.!D
M82#@`F`&X`!@)N`&P)S@Y6V,X(C`GN5B(:#A`\"<X```G.!DP2+@!<`,X&3!
M+.`,`)#@YLV`X)``GN4#,)#@90$BX`8``.`"`"#@9#&#X``PD^#LK8/@F`">
MY2PXG^5F8:#A`P"0X*!`GN4"()#@90$FX`P`(.``()+@`P"4X&4!@.#J38+@
MJ%">Y6PA)N`*("+@`@"0X&HAH.$#4)7@L*">Y090E>!L82+@!&`FX.0-@.`&
M4)7@`V":X&QAAN"XH)[EX,V%X&11(N``4"7@!6"6X&`!H.$#4)K@`E"5X,"@
MGN7L+8;@9&$@X`Q@)N`&4)7@`V":X&1AAN#(H)[E;$$@X`)`).#B787@!&"6
MX&(AH.$#0)K@``"4X-"@GN5L02+@!4`DX`1`D.`#`)K@Y6V&X-B@GN5L`8#@
M9<$BX`;`+.#F383@#`"0X&9AH.$#P)K@`B"<X."@GN5EP2;@!,`LX`S`DN`#
M()K@Y`V`X.B@GN5E(8+@9%$FX`!0)>#@S8S@!2"2X&`!H.$#4)K@!E"5X/B@
MGN7P8)[E9.$@X`S@+N#L+8+@#N"5X.)=CN`#8);@;.$@X&1!AN`"X"[@#N"4
MX&(AH.$#0)K@`$"4X!AAG>5L`2+@!0`@X.7MCN```)3@`V"6X.Y-@.!LP8;@
M90$BX"!AG>4.`"#@``"<X&[AH.$#8);@`B"6X&7!+N`H89WE!,`LX.0-@.`,
MP)+@`R"6X&4A@N`P89WEX%V,X&3!+N``P"S@#,"2X&`!H.$#8);@Y2V,X`[@
MEN!DP2#@.&&=Y07`+.`,P)[@`^"6X&3ACN!`89WE94$@X`)`).#BS8S@!.">
MX&(AH.$#8);@``"6X&5!(N!(89WE#$`DX.SMCN!0H9WE!$"0X`,`EN#L-9_E
M;&$BX&4!@.`.8";@;E&@X>Y-A.`&8)#@;.&%X0,`FN`"`)#@6*&=Y>0MAN`$
MX`[@;&$%X`;@CN$.X)#@`Z":X&0!A>%D807@;,&*X`(``.!@H9WE!@"`X>+M
MCN`,`)#@8B&@X0/`FN`%P)S@9%&"X61A`N!HH9WE#E`%X`90A>'N#8#@#%"5
MX`.@FN!NP8+A;F$"X&1!BN``P`S@<*&=Y0;`C.'@787@!$"<X&`!H.$#P)K@
M`L"<X.4MA.!N08#A;F$`X'BAG>4%0`3@!D"$X0Q`E.`#H)K@9<&`X65A`.!N
MX8K@`L`,X("AG>4&P(SAXDV$X`[@G.!B(:#A`\":X`#`G.#D#8[@9>&"X65A
M`N"(H9WE!.`.X`;@CN$,X)[@`Z":X&3!@N%D80+@95&*X`#`#."0H9WE!L",
MX>#MCN`%4)S@8`&@X0/`FN`"P)S@[BV%X&11@.%D80#@F*&=Y0Y0!>`&4(7A
M#%"5X`.@FN!NP8#A;F$`X&1!BN`"P`S@H*&=Y0;`C.'B787@!$"<X&(AH.$#
MP)K@`,"<X.4-A.!N08+A;F$"X*BAG>4%0`3@!D"$X0Q`E.`#H)K@9<&"X65A
M`N!NX8K@`,`,X+"AG>4&P(SAX$V$X`[@G.!@`:#A`\":X`+`G.#D+8[@9>&`
MX65A`."XH9WE!.`.X`;@CN$,X)[@`Z":X&3!@.%D80#@95&*X`+`#.#`H9WE
M!L",X>+MCN`%4)S@8B&@X0/`FN``P)S@[@V%X&11@N'(H9WE9&$"X`Y0!>`&
M4(7A#%"5X`.@FN!NP8+A;F$"X&1!BN``P`S@T*&=Y0;`C.'@787@!$"<X&`!
MH.$#P)K@`&"@XP+`G.#E+83@;D&`X05`!.`$8('E#&"!Y11@@>4<8('E;F$`
MX-BAG>4&0(3A#$"4X&7!@.$#H)K@96$`X`+`#.!NX8K@!L",X>"AG>7B383@
M#L"<X&(AH.'D[8S@`Z":X&7!@N%E80+@``":X`3`#.#HH9WE!L",X0#`G.`#
MH)K@9`&"X>@RG^5D80+@95&*X`X``.#PH9WE!@"`X>[-C.`%`)#@;N&@X0-0
MFN`"4)7@^&&=Y60A+N`,("+@[`V`X`(@E>`#8);@X%V"X&1!AN!L(2[@`&*=
MY0`@(N`"()3@8`&@X0-`EN`.0)3@"&*=Y6SA(.`%X"[@#N"4X`-`EN#E+8+@
M$&*=Y6Q!A.!EP2#@`L`LX.+MCN`,P)3@8B&@X0-`EN``0)3@&&*=Y64!(N`.
M`"#@[LV,X```E.`#0);@94&$X"!BG>7L78#@;@$BX`P`(.```)3@;,&@X0-`
MEN`"0)3@*&*=Y6XA+.`%("+@Y0V`X`(@E.`#8);@X$V"X&[AAN!E(2S@,&*=
MY0`@(N`"()[@8`&@X0/@EN`,X)[@.&*=Y67!(.`$P"S@Y"V"X`S`GN`#X);@
M9>&.X$!BG>7B78S@9,$@X`+`+.`,P)[@8B&@X0/@EN``X)[@2&*=Y60!(N`%
M`"#@Y<V,X```GN`#X);@9.&.X%!BG>7L38#@90$BX`P`(.```)[@;,&@X0/@
MEN`"X)[@6&*=Y64A+.`$("+@Y`V`X`(@GN`#X);@9>&.X&!BG>7@78+@9"$L
MX``@(N`"()[@8`&@X0/@EN`,X)[@:&*=Y63!(.`%P"S@Y2V"X`S`GN`#X);@
M9.&.X'!BG>7B38S@9<$@X`+`+.`,P)[@8B&@X0/@EN``X)[@>&*=Y64!(N`$
M`"#@``">X`/@EN#DS8S@9>&.X&1A(N"`4IWE#&`FX.P-@.`&X)[@;,&@X0-0
ME>`"()7@9&$LX(A2G>4`8";@!B"2X`,PE>#@[8[@8)&)X`@PD^!@`2S@#@`@
MX&0Q@^``,)/@[BV"X.(]@^!N<8?@"R"2X"``D>48D('E$'"!Y0`P@>4((('E
M4""?Y3@PG^4"((_@`,"<X`!@H.,@P('E)&"!Y0,PDN<`()/EE#*=Y0(@,^``
M,*#C`0``&J??C>+PC[WHC//_Z_S%`0`<`0``F7F"6J'KV6[<O!N/UL%BRMBY
M`0!P0"WI@`"@XW_S_^M04(_BT$#%X0`@H./P0,#A2%"/XM!`Q>%X((#E^$#`
MX4!0C^+00,7A\$'`X3Q0C^+00,7A^$'`X3A0C^+00,7A\$+`X0!`H.,`4*#C
M^$+`X?!#P.%P@+WH`2-%9P````")J\WO`````/[<NI@`````=E0R$`````#P
MX=+#`````/!'+>DH,)#E`F"@X8;!@^`L()#E`P!<X0`PH.,"(-/@`%"@X3`@
MD.4!0*#A-!"0Y<8/H.$!```J`2"2X@`0H>(L,(7EICZ@X8`Q@^$",)/@H!ZA
MX'@`E>4X@(7B``!0XRC`A>4P,(7E-!"%Y18``!H_`%;C)0``VD!@1N(FDZ#A
M`7")X@=SA.`$$*#A0""@XP@`H.$8\__K0$"$X@4`H.&2_/_K!P!4X?;__QH)
MG6G@"6.&X`8@H.$'$*#A"`"@X0WS_^MX8(7E\(>]Z$!P8.(&`%?A!G"@H0``
MB.`'(*#A!!"@X03S_^MX,)7E`S"'X$``4^-X,(7E\(>]&`4`H.$'8$;@!T"$
MX'C\_^O7___J!'"@X>;__^KP02WI*#"1Y0%`H.%C*"/@,!"1Y2(DH.'_+,+C
M8W0BX&$H(>"C,:#A(B2@X3\P`^+_+,+C860BX`$@@^(X@(3B?Q#@XS@`4N,`
M4*#A`Q#(YP(`B.`\``#:0"!BX@`0H..U\O_K!`"@X5K\_^L(`*#A.""@XP`0
MH..O\O_K!`"@X7!@A.5T<(3E4OS_ZP,PU.4`,,7ELC#4X0$PQ>4`,)3E!`"@
MX2,TH.$",,7E`#"4Y0,PQ>4+,-3E!##%Y;HPU.$%,,7E"#"4Y2,TH.$&,,7E
M"#"4Y0<PQ>43,-3E"##%Y;(QU.$),,7E$#"4Y2,TH.$*,,7E$#"4Y0LPQ>4;
M,-3E###%Y;HQU.$-,,7E&#"4Y2,TH.$.,,7E&#"4Y0\PQ>4C,-3E$##%Y;(R
MU.$1,,7E(#"4Y2,TH.$2,,7E(#"4Y1,PQ>7P0;WHBO+_ZC@@8N(`$*#C>/+_
MZ\?__^H````````````````/"N#C'_!`X@@PG^4#,(_@`#"3Y<[R_^J@MP$`
M"$`MZ0B`O>@!``(`/0```$`````+````0````!````!`````)@```$`````U
M````0`````,```!`````!@```$`````4````0`````X```!`````#0```$``
M```E````0````!(```!`````*````$`````"````0````!@```!`````"0``
M`$`````*````0```````````````)7,O)7,````O<')O8R]S96QF+V5X90``
M1'EN84QO861E<CHZ8F]O=%]$>6YA3&]A9&5R`$EN=&5R;F%L<SHZ4$%2.CI"
M3T]4`````"]P<F]C+R5I+R5S`&5X90`N````4$%27U1%35``````4$%27U!2
M3T=.04U%`````#H````E<R5S)7,``"\```!015),-4Q)0@````!015),3$E"
M`%!%4DPU3U!4`````%!%4DQ)3P``4$%27TE.251)04Q)6D5$`%!!4E]34$%7
M3D5$`%!!4E]#3$5!3@```%!!4E]$14)51P```%!!4E]#04-(10```%!!4E]'
M3$]"04Q?1$5"54<`````4$%27T=,3T)!3%]435!$25(```!005)?5$U01$E2
M``!005)?1TQ/0D%,7U1%35``4$%27T=,3T)!3%]#3$5!3@`````Q````3$1?
M3$E"4D%265]0051(`%-94U1%30``)3`R>``````E<R5S)7,E<P````!P87(M
M`````"5S.B!C<F5A=&EO;B!O9B!P<FEV871E('-U8F1I<F5C=&]R>2`E<R!F
M86EL960@*&5R<FYO/25I*0H``"5S.B!P<FEV871E('-U8F1I<F5C=&]R>2`E
M<R!I<R!U;G-A9F4@*'!L96%S92!R96UO=F4@:70@86YD(')E=')Y('EO=7(@
M;W!E<F%T:6]N*0H``%!!5$@`````<&%R;``````N<&%R`````"5S)7-C86-H
M92TE<R5S```E<R5S=&5M<"TE=25S````)7,E<W1E;7`M)74M)74E<P`````8
M````<&5R;``````P````4$%2.CI086-K97(Z.E9%4E-)3TX`````,2XP-3<`
M``!5;F%B;&4@=&\@8W)E871E(&-A8VAE(&1I<F5C=&]R>0`````E<SH@8W)E
M871I;VX@;V8@<')I=F%T92!C86-H92!S=6)D:7)E8W1O<GD@)7,@9F%I;&5D
M("AE<G)N;STE:2D*`````"UE```M+0``55-%4@````!54T523D%-10````!4
M14U01$E2`%1-4``O=&UP`````&5V86P@)V5X96,@+W5S<B]B:6XO<&5R;"`@
M+5,@)#`@)'LQ*R(D0")])PII9B`P.R`C(&YO="!R=6YN:6YG('5N9&5R('-O
M;64@<VAE;&P*<&%C:V%G92!?7W!A<E]P;#L*;7D@*"1005)?34%'24,L("1&
M24Q%7V]F9G-E=%]S:7IE+"`D8V%C:&5?;F%M95]S:7IE*3L*0D5'24X@>PHD
M4$%27TU!1TE#(#T@(EQN4$%2+G!M7&XB.PHD1DE,15]O9F9S971?<VEZ92`]
M(#0[("`@(R!P86-K*").(BD*)&-A8VAE7VYA;65?<VEZ92`](#0P.PHD4$M:
M25!?34%'24,@/2`B4$M<,#`S7#`P-"(["GT*<W5B(&9I;F1?<&%R7VUA9VEC
M"GL*;7D@*"1F:"D@/2!`7SL*;7D@)&-H=6YK7W-I>F4@/2`V-"`J(#$P,C0[
M"FUY("1B=68["FUY("1S:7IE(#T@+7,@)&9H.PIM>2`D<&]S(#T@*"1S:7IE
M+3$I("T@*"1S:7IE+3$I("4@)&-H=6YK7W-I>F4[("`@("`@(R!.3U1%.B`D
M<&]S(&ES(&$@;75L=&EP;&4@;V8@)&-H=6YK7W-I>F4*=VAI;&4@*"1P;W,@
M/CT@,"D@>PIS965K("1F:"P@)'!O<RP@,#L*<F5A9"`D9F@L("1B=68L("1C
M:'5N:U]S:7IE("L@;&5N9W1H*"1005)?34%'24,I.PII9B`H*&UY("1I(#T@
M<FEN9&5X*"1B=68L("1005)?34%'24,I*2`^/2`P*2!["G)E='5R;B`D<&]S
M("L@)&D["GT*)'!O<R`M/2`D8VAU;FM?<VEZ93L*?0IR971U<FX@+3$["GT*
M;7D@*"1P87)?=&5M<"P@)'!R;V=N86UE+"!`=&UP9FEL92P@)4UO9'5L94-A
M8VAE*3L*14Y$('L@:68@*"1%3E9[4$%27T-,14%.?2D@>PIR97%U:7)E($9I
M;&4Z.E1E;7`["G)E<75I<F4@1FEL93HZ0F%S96YA;64["G)E<75I<F4@1FEL
M93HZ4W!E8SL*;7D@)'1O<&1I<B`]($9I;&4Z.D)A<V5N86UE.CID:7)N86UE
M*"1P87)?=&5M<"D["F]U=',H<7%;4F5M;W9I;F<@9FEL97,@:6X@(B1P87)?
M=&5M<")=*3L*1FEL93HZ1FEN9#HZ9FEN9&1E<'1H*'-U8B![("@@+60@*2`_
M(')M9&ER(#H@=6YL:6YK('TL("1P87)?=&5M<"D["G)M9&ER("1P87)?=&5M
M<#L*:68@*"UD("1P87)?=&5M<"`F)B`D7D\@;F4@)TU35VEN,S(G*2!["FUY
M("1T;7`@/2!N97<@1FEL93HZ5&5M<"@*5$5-4$Q!5$4@/3X@)W1M<%A86%A8
M)RP*1$E2(#T^($9I;&4Z.D)A<V5N86UE.CID:7)N86UE*"1T;W!D:7(I+`I3
M549&25@@/3X@)RYC;60G+`I53DQ)3DL@/3X@,"P**3L*;7D@)&9I;&5N86UE
M(#T@)'1M<"T^9FEL96YA;64["G!R:6YT("1T;7`@/#PB+BXN(CL*>#TQ.R!W
M:&EL92!;(%PD>"`M;'0@,3`@73L@9&\*<FT@+7)F("<D<&%R7W1E;7`G"FEF
M(%L@7"$@+60@)R1P87)?=&5M<"<@73L@=&AE;@IB<F5A:PIF:0IS;&5E<"`Q
M"G@]8&5X<'(@7"1X("L@,6`*9&]N90IR;2`G)&9I;&5N86UE)PHN+BX*8VQO
M<V4@)'1M<#L*8VAM;V0@,#<P,"P@)&9I;&5N86UE.PIM>2`D8VUD(#T@(B1F
M:6QE;F%M92`^+V1E=B]N=6QL(#(^)C$@)B(["G-Y<W1E;2@D8VUD*3L*;W5T
M<RAQ<5M3<&%W;F5D(&)A8VMG<F]U;F0@<')O8V5S<R!T;R!P97)F;W)M(&-L
M96%N=7`Z("1F:6QE;F%M95TI.PI]"GT@?0I"14=)3B!["DEN=&5R;F%L<SHZ
M4$%2.CI"3T]4*"D@:68@9&5F:6YE9"`F26YT97)N86QS.CI005(Z.D)/3U0[
M"F5V86P@>PI?<&%R7VEN:71?96YV*"D["FUY("1Q=6EE="`]("$D14Y6>U!!
M4E]$14)51WT["FUY("5S>7,@/2`H"G!A=&A?<V5P("`@(#T^("@D7D\@/7X@
M+UY-4U=I;B\@/R`G.R<@.B`G.B<I+`I?97AE("`@("`@("`]/B`H)%Y/(#U^
M("]>*#\Z35-7:6Y\3U,R?&-Y9W=I;BDO(#\@)RYE>&4G(#H@)R<I+`I?9&5L
M:6T@("`@("`]/B`H)%Y/(#U^("]>35-7:6Y\3U,R+R`_("=<7"<@.B`G+R<I
M+`HI.PI?<V5T7W!R;V=N86UE*"D["F]U=',H<7%;7"1P<F]G;F%M92`]("(D
M<')O9VYA;64B72D["E]S971?<&%R7W1E;7`H*3L*;W5T<RAQ<5M<)$5.5GM0
M05)?5$5-4'T@/2`B)$5.5GM005)?5$5-4'TB72D["FUY("@D<W1A<G1?<&]S
M+"`D<W1A<G1?;V9?1DE,15]S96-T:6]N*3L*34%'24,Z('L*;&]C86P@)%-)
M1WM?7U=!4DY?7WT@/2!S=6(@>WT["G5N;&5S<R`H;W!E;B!?1D@L("<\.G)A
M=R<L("1P<F]G;F%M92D@>PIO=71S*'%Q6T-A;B=T(')E860@9G)O;2!F:6QE
M("(D<')O9VYA;64B72D[("`C(&1O;B=T('5S92`D(2!H97)E(&%S(&ET(')E
M<75I<F5S($5R<FYO+G!M"FQA<W0@34%'24,["GT*;7D@)&UA9VEC7W!O<R`]
M(&9I;F1?<&%R7VUA9VEC*"I?1D@I.PII9B`H)&UA9VEC7W!O<R`\(#`I('L*
M;W5T<RAQ<5M#86XG="!F:6YD(&UA9VEC('-T<FEN9R`B)%!!4E]-04=)0R(@
M:6X@9FEL92`B)'!R;V=N86UE(ETI.PIL87-T($U!1TE#.PI]"F]U=',H(D9O
M=6YD(%!!4B!M86=I8R!A="!P;W-I=&EO;B`D;6%G:6-?<&]S(BD["G-E96L@
M7T9(+"`D;6%G:6-?<&]S("T@)$9)3$5?;V9F<V5T7W-I>F4@+2!L96YG=&@H
M(EPP0T%#2$4B*2P@,#L*<F5A9"!?1D@L("1B=68L(&QE;F=T:"@B7#!#04-(
M12(I.PII9B`H)&)U9B!N92`B7#!#04-(12(@)B8@)&)U9B!N92`B7#!#3$5!
M3B(I('L*;W5T<R@B3F\@8V%C:&4@;6%R:V5R(&9O=6YD(BD["FQA<W0@34%'
M24,["GT*;W5T<RAQ<5M#86-H92!M87)K97(@(B1B=68B(&9O=6YD72D["G-E
M96L@7T9(+"`D;6%G:6-?<&]S("T@)$9)3$5?;V9F<V5T7W-I>F4L(#`["G)E
M860@7T9(+"`D8G5F+"`D1DE,15]O9F9S971?<VEZ93L*;7D@)&]F9G-E="`]
M('5N<&%C:R@B3B(L("1B=68I.PIO=71S*")/9F9S970@9G)O;2!S=&%R="!O
M9B!&24Q%<R!I<R`D;V9F<V5T(BD["G-E96L@7T9(+"`D;6%G:6-?<&]S("T@
M)$9)3$5?;V9F<V5T7W-I>F4@+2`D;V9F<V5T+"`P.PHD<W1A<G1?;V9?1DE,
M15]S96-T:6]N(#T@=&5L;"!?1D@["FUY("5R97%U:7)E7VQI<W0["G)E860@
M7T9(+"`D8G5F+"`T.R`@("`@("`@("`@("`@("`@("`@("`@("`@(",@<F5A
M9"!T:&4@9FER<W0@(D9)3$4B"G=H:6QE("@D8G5F(&5Q(")&24Q%(BD@>PIR
M96%D(%]&2"P@)&)U9BP@-#L*<F5A9"!?1D@L("1B=68L('5N<&%C:R@B3B(L
M("1B=68I.PIM>2`D9G5L;&YA;64@/2`D8G5F.PIO=71S*'%Q6U5N<&%C:VEN
M9R!&24Q%("(D9G5L;&YA;64B+BXN72D["FUY("1C<F,@/2`H("1F=6QL;F%M
M92`]?B!S?%XH6V$M9EQD77LX?2DO?'P@*2`_("0Q(#H@=6YD968["FUY("@D
M8F%S96YA;64L("1E>'0I(#T@*"1B=68@/7X@;7PH/SHN*B\I/R@N*BDH7"XN
M*BE\*3L*<F5A9"!?1D@L("1B=68L(#0["G)E860@7T9(+"`D8G5F+"!U;G!A
M8VLH(DXB+"`D8G5F*3L*:68@*&1E9FEN960H)&5X="D@86YD("1E>'0@(7X@
M+UPN*#\Z<&U\<&Q\:7A\86PI)"]I*2!["FUY("1F:6QE;F%M92`](%]S879E
M7V%S*"(D8W)C)&5X="(L("1B=68L(#`W-34I.PHD4$%2.CI(96%V>3HZ1G5L
M;$-A8VAE>R1F=6QL;F%M97T@/2`D9FEL96YA;64["B1005(Z.DAE879Y.CI&
M=6QL0V%C:&5[)&9I;&5N86UE?2`]("1F=6QL;F%M93L*?0IE;'-I9B`H("1F
M=6QL;F%M92`]?B!M?%XO/W-H;&EB+WP@86YD(&1E9FEN960@)$5.5GM005)?
M5$5-4'T@*2!["FUY("1F:6QE;F%M92`](%]S879E7V%S*"(D8F%S96YA;64D
M97AT(BP@)&)U9BP@,#<U-2D["F]U=',H(E-(3$E".B`D9FEL96YA;65<;B(I
M.PI]"F5L<V4@>PHD36]D=6QE0V%C:&5[)&9U;&QN86UE?2`]('L*8G5F(#T^
M("1B=68L"F-R8R`]/B`D8W)C+`IN86UE(#T^("1F=6QL;F%M92P*?3L*)')E
M<75I<F5?;&ES='LD9G5L;&YA;65]*RL["GT*<F5A9"!?1D@L("1B=68L(#0[
M"GT*;&]C86P@0$E.0R`]("AS=6(@>PIM>2`H)'-E;&8L("1M;V1U;&4I(#T@
M0%\["G)E='5R;B!I9B!R968@)&UO9'5L92!O<B`A)&UO9'5L93L*;7D@)&EN
M9F\@/2`D36]D=6QE0V%C:&5[)&UO9'5L97T["G)E='5R;B!U;FQE<W,@)&EN
M9F\["F1E;&5T92`D<F5Q=6ER95]L:7-T>R1M;V1U;&5].PHD24Y#>R1M;V1U
M;&5](#T@(B]L;V%D97(O)&EN9F\O)&UO9'5L92(["FEF("@D14Y6>U!!4E]#
M3$5!3GT@86YD(&1E9FEN960H)DE/.CI&:6QE.CIN97<I*2!["FUY("1F:"`]
M($E/.CI&:6QE+3YN97=?=&UP9FEL92!O<B!D:64@(D-A;B=T(&-R96%T92!T
M96UP(&9I;&4Z("0A(CL*)&9H+3YB:6YM;V1E*"D["B1F:"T^<')I;G0H)&EN
M9F\M/GMB=69]*3L*)&9H+3YS965K*#`L(#`I.PIR971U<FX@)&9H.PI]"F5L
M<V4@>PIM>2`D9FEL96YA;64@/2!?<V%V95]A<R@B)&EN9F\M/GMC<F-]+G!M
M(BP@)&EN9F\M/GMB=69]*3L*)&EN9F\M/GMF:6QE?2`]("1F:6QE;F%M93L*
M;W!E;B!M>2`D9F@L("<\.G)A=R<L("1F:6QE;F%M92!O<B!D:64@<7%;0V%N
M)W0@<F5A9"`B)&9I;&5N86UE(CH@)"%=.PIR971U<FX@)&9H.PI]"F1I92`B
M0F]O='-T<F%P<&EN9R!F86EL960Z(&-A;B=T(&9I;F0@;6]D=6QE("1M;V1U
M;&4A(CL*?2P@0$E.0RD["G)E<75I<F4@6%-,;V%D97(["G)E<75I<F4@4$%2
M.CI(96%V>3L*<F5Q=6ER92!#87)P.CI(96%V>3L*<F5Q=6ER92!%>'!O<G1E
M<CHZ2&5A=GD["E!!4CHZ2&5A=GDZ.E]I;FET7V1Y;F%L;V%D97(H*3L*<F5Q
M=6ER92!)3SHZ1FEL93L*=VAI;&4@*&UY("1F:6QE;F%M92`]("AS;W)T(&ME
M>7,@)7)E<75I<F5?;&ES="E;,%TI('L*=6YL97-S("@D24Y#>R1F:6QE;F%M
M97T@;W(@)&9I;&5N86UE(#U^("]"4T1004XO*2!["FEF("@D9FEL96YA;64@
M/7X@+UPN<&UC/R0O:2D@>PIR97%U:7)E("1F:6QE;F%M93L*?0IE;'-E('L*
M9&\@)&9I;&5N86UE('5N;&5S<R`D9FEL96YA;64@/7X@+W-I=&5C=7-T;VUI
M>F5<+G!L)"\["GT*?0ID96QE=&4@)')E<75I<F5?;&ES='LD9FEL96YA;65]
M.PI]"FEF("@D8G5F(&YE("102UI)4%]-04=)0RD@>PIO=71S*'%Q6TYO('II
M<"!F;W5N9"!A9G1E<B!&24Q%('-E8W1I;VX@:6X@9FEL92`B)'!R;V=N86UE
M(ETI.PIL87-T($U!1TE#(#L*?0HD<W1A<G1?<&]S(#T@*'1E;&P@7T9(*2`M
M(#0[("`@("`@("`@("`@("`@(",@<W1A<G0@;V8@>FEP"GT*;7D@0'!A<E]A
M<F=S.PIM>2`H)&]U="P@)&)U;F1L92P@)&QO9V9H+"`D8V%C:&5?;F%M92D[
M"F1E;&5T92`D14Y6>U!!4E]!4%!?4D554T5].R`C('-A;FET:7IE("A21553
M12!M87D@8F4@82!S96-U<FET>2!P<F]B;&5M*0II9B`H(21S=&%R=%]P;W,@
M;W(@*"1!4D=66S!=(&5Q("<M+7!A<BUO<'1I;VYS)R`F)B!S:&EF="DI('L*
M;7D@)61I<W1?8VUD(#T@<7<H"G`@("!B;&EB7W1O7W!A<@II("`@:6YS=&%L
M;%]P87(*=2`@('5N:6YS=&%L;%]P87(*<R`@('-I9VY?<&%R"G8@("!V97)I
M9GE?<&%R"BD["FEF("A`05)'5B!A;F0@)$%21U9;,%T@97$@)RTM<F5U<V4G
M*2!["G-H:69T($!!4D=6.PHD14Y6>U!!4E]!4%!?4D554T5](#T@<VAI9G0@
M0$%21U8["GT*96QS92![(",@;F]R;6%L('!A<FP@8F5H879I;W5R"FUY($!A
M9&1?=&]?:6YC.PIW:&EL92`H0$%21U8I('L*)$%21U9;,%T@/7X@+UXM*%M!
M24U/0DQB<7!I=7-4=ETI*"XJ*2\@;W(@;&%S=#L*:68@*"0Q(&5Q("=))RD@
M>PIP=7-H($!A9&1?=&]?:6YC+"`D,CL*?0IE;'-I9B`H)#$@97$@)TTG*2![
M"F5V86P@(G5S92`D,B(["GT*96QS:68@*"0Q(&5Q("=!)RD@>PIU;G-H:69T
M($!P87)?87)G<RP@)#(["GT*96QS:68@*"0Q(&5Q("=/)RD@>PHD;W5T(#T@
M)#(["GT*96QS:68@*"0Q(&5Q("=B)RD@>PHD8G5N9&QE(#T@)W-I=&4G.PI]
M"F5L<VEF("@D,2!E<2`G0B<I('L*)&)U;F1L92`]("=A;&PG.PI]"F5L<VEF
M("@D,2!E<2`G<2<I('L*)'%U:65T(#T@,3L*?0IE;'-I9B`H)#$@97$@)TPG
M*2!["F]P96X@)&QO9V9H+"`B/CXB+"`D,B!O<B!D:64@<7%;0V%N)W0@;W!E
M;B!L;V<@9FEL92`B)#(B.B`D(5T["GT*96QS:68@*"0Q(&5Q("=4)RD@>PHD
M8V%C:&5?;F%M92`]("0R.PI]"G-H:69T*$!!4D=6*3L*:68@*&UY("1C;60@
M/2`D9&ES=%]C;61[)#%]*2!["F1E;&5T92`D14Y6>R=005)?5$5-4"=].PII
M;FET7VEN8R@I.PIR97%U:7)E(%!!4CHZ1&ES=#L*)GLB4$%2.CI$:7-T.CHD
M8VUD(GTH*2!U;FQE<W,@0$%21U8["B9[(E!!4CHZ1&ES=#HZ)&-M9")]*"1?
M*2!F;W(@0$%21U8["F5X:70["GT*?0IU;G-H:69T($!)3D,L($!A9&1?=&]?
M:6YC.PI]"GT*:68@*"1O=70I('L*>PIR97%U:7)E($E/.CI&:6QE.PIR97%U
M:7)E($%R8VAI=F4Z.EII<#L*<F5Q=6ER92!$:6=E<W0Z.E-(03L*?0IM>2`D
M<&%R(#T@<VAI9G0H0$%21U8I.PIM>2`D>FEP.PII9B`H9&5F:6YE9"`D<&%R
M*2!["F]P96X@;7D@)&9H+"`G/#IR87<G+"`D<&%R(&]R(&1I92!Q<5M#86XG
M="!F:6YD('!A<B!F:6QE("(D<&%R(CH@)"%=.PIB;&5S<R@D9F@L("=)3SHZ
M1FEL92<I.PHD>FEP(#T@07)C:&EV93HZ6FEP+3YN97<["B@@)'II<"T^<F5A
M9$9R;VU&:6QE2&%N9&QE*"1F:"P@)'!A<BD@/3T@07)C:&EV93HZ6FEP.CI!
M6E]/2R@I("D*;W(@9&EE('%Q6T5R<F]R(')E861I;F<@>FEP(&%R8VAI=F4@
M(B1P87(B73L*?0IM>2`E;65T85]P87(@/2!D;R!["FEF("@D>FEP(&%N9"!M
M>2`D;65T82`]("1Z:7`M/F-O;G1E;G1S*"=-151!+GEM;"<I*2!["B1M971A
M(#U^(',O+BI><&%R.B0O+VUS.PHD;65T82`]?B!S+UY<4RXJ+R]M<SL*)&UE
M=&$@/7X@+UX@("A;7CI=*RDZ("@N*RDD+VUG.PI]"GT["FEF("AD969I;F5D
M("1P87(I('L*;W!E;B!M>2`D<&@L("<\.G)A=R<L("1P87(@;W(@9&EE('%Q
M6T-A;B=T(')E860@<&%R(&9I;&4@(B1P87(B.B`D(5T["FUY("1B=68["G)E
M860@)'!H+"`D8G5F+"`T.PID:64@<7%;(B1P87(B(&ES(&YO="!A('!A<B!F
M:6QE72!U;FQE<W,@)&)U9B!E<2`D4$M:25!?34%'24,["F-L;W-E("1P:#L*
M?0I#<F5A=&50871H*"1O=70I(#L*;7D@)&9H(#T@24\Z.D9I;&4M/FYE=R@*
M)&]U="P*24\Z.D9I;&4Z.D]?0U)%050H*2!\($E/.CI&:6QE.CI/7U)$5U(H
M*2!\($E/.CI&:6QE.CI/7U1254Y#*"DL"C`W-S<L"BD@;W(@9&EE('%Q6T-A
M;B=T(&-R96%T92!F:6QE("(D;W5T(CH@)"%=.PHD9F@M/F)I;FUO9&4H*3L*
M<V5E:R!?1D@L(#`L(#`["FUY("1L;V%D97(["FEF("AD969I;F5D("1S=&%R
M=%]O9E]&24Q%7W-E8W1I;VXI('L*<F5A9"!?1D@L("1L;V%D97(L("1S=&%R
M=%]O9E]&24Q%7W-E8W1I;VX["GT@96QS92!["FQO8V%L("0O(#T@=6YD968[
M"B1L;V%D97(@/2`\7T9(/CL*?0II9B`H(21%3E9[4$%27U9%4D)!5$E-?2!A
M;F0@)&QO861E<B`]?B`O7B@_.B,A?%Q`<F5M*2\I('L*<F5Q=6ER92!005(Z
M.D9I;'1E<CHZ4&]D4W1R:7`["E!!4CHZ1FEL=&5R.CI0;V13=')I<"T^87!P
M;'DH7"1L;V%D97(L("0P*3L*?0HD9F@M/G!R:6YT*"1L;V%D97(I"F]R(&1I
M92!Q<5M%<G)O<B!W<FET:6YG(&QO861E<B!T;R`B)&]U="(Z("0A73L*:68@
M*"1B=6YD;&4I('L*<F5Q=6ER92!005(Z.DAE879Y.PI005(Z.DAE879Y.CI?
M:6YI=%]D>6YA;&]A9&5R*"D["FEN:71?:6YC*"D["G)E<75I<F5?;6]D=6QE
M<R@I.PIM>2!`:6YC(#T@9W)E<"![("$O0E-$4$%.+R!]"F=R97`@>PHH)&)U
M;F1L92!N92`G<VET92<I(&]R"B@D7R!N92`D0V]N9FEG.CI#;VYF:6=[87)C
M:&QI8F5X<'T@86YD"B1?(&YE("1#;VYF:6<Z.D-O;F9I9WMP<FEV;&EB97AP
M?2D["GT@0$E.0SL*<WPO*WPO?&<L('-\+R1\?"!F;W)E86-H($!I;F,["FUY
M("5F:6QE<SL*)&9I;&5S>R1??2LK(&9O<B!`1'EN84QO861E<CHZ9&Q?<VAA
M<F5D7V]B:F5C=',L('9A;'5E<R`E24Y#.PIM>2`D;&EB7V5X="`]("1#;VYF
M:6<Z.D-O;F9I9WML:6)?97AT?3L@("`@("`@("`C(%A86"!L:6)?97AT('9S
M(&1L97AT(#\*;7D@)7=R:71T96X["F9O<F5A8V@@;7D@)&ME>2`H<V]R="!K
M97ES("5F:6QE<RD@>PIM>2`H)&9I;&4L("1N86UE*3L*:68@*&1E9FEN960H
M;7D@)&9C(#T@)%!!4CHZ2&5A=GDZ.D9U;&Q#86-H97LD:V5Y?2DI('L**"1F
M:6QE+"`D;F%M92D@/2`H)&ME>2P@)&9C*3L*?0IE;'-E('L*9F]R96%C:"!M
M>2`D9&ER("A`:6YC*2!["FEF("@D:V5Y(#U^(&U\7EQ1)&1I<EQ%+R@N*BDD
M?&DI('L**"1F:6QE+"`D;F%M92D@/2`H)&ME>2P@)#$I.PIL87-T.PI]"FEF
M("@D:V5Y(#U^(&U\7B]L;V%D97(O6UXO72LO*"XJ*21\*2!["FEF("AM>2`D
M<F5F(#T@)$UO9'5L94-A8VAE>R0Q?2D@>PHH)&9I;&4L("1N86UE*2`]("@D
M<F5F+"`D,2D["FQA<W0["GT*:68@*"UF("(D9&ER+R0Q(BD@>PHH)&9I;&4L
M("1N86UE*2`]("@B)&1I<B\D,2(L("0Q*3L*;&%S=#L*?0I]"GT*?0IN97AT
M('5N;&5S<R!D969I;F5D("1N86UE.PIN97AT(&EF("1W<FET=&5N>R1N86UE
M?2LK.PIN97AT(&EF("%R968H)&9I;&4I(&%N9"`D9FEL92`]?B`O7"Y<421L
M:6)?97AT7$4D+VD["F]U=',H<W!R:6YT9BAQ<5M086-K:6YG($9)3$4@(B5S
M(BXN+ETL(')E9B`D9FEL92`_("1F:6QE+3Y[;F%M97T@.B`D9FEL92DI.PIM
M>2`D8V]N=&5N=#L*:68@*')E9B@D9FEL92DI('L*)&-O;G1E;G0@/2`D9FEL
M92T^>V)U9GT["GT*96QS92!["FQO8V%L("0O(#T@=6YD968["F]P96X@;7D@
M)'1H+"`G/#IR87<G+"`D9FEL92!O<B!D:64@<7%;0V%N)W0@<F5A9"`B)&9I
M;&4B.B`D(5T["B1C;VYT96YT(#T@/"1T:#X["F-L;W-E("1T:#L*4$%2.CI&
M:6QT97(Z.E!O9%-T<FEP+3YA<'!L>2A<)&-O;G1E;G0L("(\96UB961D960^
M+R1N86UE(BD*:68@(21%3E9[4$%27U9%4D)!5$E-?2!A;F0@)&YA;64@/7X@
M+UPN*#\Z<&U\:7A\86PI)"]I.PI005(Z.D9I;'1E<CHZ4&%T8VA#;VYT96YT
M+3YN97<M/F%P<&QY*%PD8V]N=&5N="P@)&9I;&4L("1N86UE*3L*?0HD9F@M
M/G!R:6YT*")&24Q%(BP*<&%C:R@G3B<L(&QE;F=T:"@D;F%M92D@*R`Y*2P*
M<W!R:6YT9B@B)3`X>"\E<R(L($%R8VAI=F4Z.EII<#HZ8V]M<'5T94-20S,R
M*"1C;VYT96YT*2P@)&YA;64I+`IP86-K*"=.)RP@;&5N9W1H*"1C;VYT96YT
M*2DL"B1C;VYT96YT*0IO<B!D:64@<7%;17)R;W(@=W)I=&EN9R!E;6)E9&1E
M9"!&24Q%('1O("(D;W5T(CH@)"%=.PIO=71S*'%Q6U=R:71T96X@87,@(B1N
M86UE(ETI.PI]"GT*:68@*"1Z:7`I('L*)'II<"T^=W)I=&54;T9I;&5(86YD
M;&4H)&9H*2`]/2!!<F-H:79E.CI::7`Z.D%:7T]+"F]R(&1I92!Q<5M%<G)O
M<B!W<FET:6YG('II<"!P87)T(&]F("(D;W5T(ET["GT*:68@*"1M971A7W!A
M<GMC;&5A;GTI('L*)&9H+3YP<FEN="@B7#!#3$5!3B(I.PI]"F5L<V4@>PII
M9B`H(61E9FEN960@)&-A8VAE7VYA;64I('L*;7D@)&-T>"`]($1I9V5S=#HZ
M4TA!+3YN97<H,2D["G-E96L@)&9H+"`P+"`P.PHD8W1X+3YA9&1F:6QE*"1F
M:"D["G-E96L@)&9H+"`P+"`R.PHD8V%C:&5?;F%M92`]("1C='@M/FAE>&1I
M9V5S=#L*?0HD8V%C:&5?;F%M92`]('-U8G-T<B`D8V%C:&5?;F%M92P@,"P@
M)&-A8VAE7VYA;65?<VEZ93L*)&-A8VAE7VYA;64@+CT@(EPP(B!X("@D8V%C
M:&5?;F%M95]S:7IE("T@;&5N9W1H("1C86-H95]N86UE*3L*)&9H+3YP<FEN
M="@D8V%C:&5?;F%M92P*(EPP0T%#2$4B*3L*?0IM>2`D;V9F<V5T(#T@)&9H
M+3YT96QL("T@;&5N9W1H*"1L;V%D97(I.PHD9F@M/G!R:6YT*'!A8VLH)TXG
M+"`D;V9F<V5T*2P*)%!!4E]-04=)0RD["B1F:"T^8VQO<V4@;W(@9&EE('%Q
M6T5R<F]R('=R:71I;F<@=')A:6QE<B!O9B`B)&]U="(Z("0A73L*8VAM;V0@
M,#<U-2P@)&]U=#L*97AI=#L*?0I["FQA<W0@=6YL97-S(&1E9FEN960@)'-T
M87)T7W!O<SL*7V9I>%]P<F]G;F%M92@I.PIR97%U:7)E(%!!4CL*4$%2.CI(
M96%V>3HZ7VEN:71?9'EN86QO861E<B@I.PI["G)E<75I<F4@1FEL93HZ1FEN
M9#L*<F5Q=6ER92!!<F-H:79E.CI::7`["GT*;7D@)&9H(#T@24\Z.D9I;&4M
M/FYE=SL@("`@("`@("`@("`@("`@("`@("`@("`@("`@(",@07)C:&EV93HZ
M6FEP(&]P97)A=&5S(&]N(&%N($E/.CI(86YD;&4*)&9H+3YF9&]P96XH9FEL
M96YO*%]&2"DL("=R)RD@;W(@9&EE('%Q6V9D;W!E;B@I(&9A:6QE9#H@)"%=
M.PI!<F-H:79E.CI::7`Z.G-E=$-H=6YK4VEZ92@M<R!?1D@I.PIM>2`D>FEP
M(#T@07)C:&EV93HZ6FEP+3YN97<["B@D>FEP+3YR96%D1G)O;49I;&5(86YD
M;&4H)&9H+"`D<')O9VYA;64I(#T]($%R8VAI=F4Z.EII<#HZ05I?3TLH*2D*
M;W(@9&EE('%Q6T5R<F]R(')E861I;F<@>FEP(&%R8VAI=F4@(B1P<F]G;F%M
M92)=.PI!<F-H:79E.CI::7`Z.G-E=$-H=6YK4VEZ92@V-"`J(#$P,C0I.PIP
M=7-H($!005(Z.DQI8D-A8VAE+"`D>FEP.PHD4$%2.CI,:6)#86-H97LD<')O
M9VYA;65](#T@)'II<#L*;W5T<R@B17AT<F%C=&EN9R!Z:7`N+BXB*3L*:68@
M*&1E9FEN960@)$5.5GM005)?5$5-4'TI('L@(R!S:&]U;&0@8F4@<V5T(&%T
M('1H:7,@<&]I;G0A"F9O<F5A8V@@;7D@)&UE;6)E<B`H("1Z:7`M/FUE;6)E
M<G,@*2!["FYE>'0@:68@)&UE;6)E<BT^:7-$:7)E8W1O<GD["FUY("1M96UB
M97)?;F%M92`]("1M96UB97(M/F9I;&5.86UE.PIN97AT('5N;&5S<R`D;65M
M8F5R7VYA;64@/7X@;7L*7@HO/W-H;&EB+PHH/SHD0V]N9FEG.CI#;VYF:6=[
M=F5R<VEO;GTO*3\**#\Z)$-O;F9I9SHZ0V]N9FEG>V%R8VAN86UE?2\I/PHH
M6UXO72LI"B0*?7@["FUY("1E>'1R86-T7VYA;64@/2`D,3L*;7D@)&1E<W1?
M;F%M92`]($9I;&4Z.E-P96,M/F-A=&9I;&4H)$5.5GM005)?5$5-4'TL("1E
M>'1R86-T7VYA;64I.PII9B`H+68@)&1E<W1?;F%M92`F)B`M<R!?(#T]("1M
M96UB97(M/G5N8V]M<')E<W-E9%-I>F4H*2D@>PIO=71S*'%Q6U-K:7!P:6YG
M("(D;65M8F5R7VYA;64B('-I;F-E(&ET(&%L<F5A9'D@97AI<W1S(&%T("(D
M9&5S=%]N86UE(ETI.PI](&5L<V4@>PIO=71S*'%Q6T5X=')A8W1I;F<@(B1M
M96UB97)?;F%M92(@=&\@(B1D97-T7VYA;64B+BXN72D["B@D;65M8F5R+3YE
M>'1R86-T5&]&:6QE3F%M960H)&1E<W1?;F%M92D@/3T@07)C:&EV93HZ6FEP
M.CI!6E]/2R@I*0IO<B!D:64@<7%;17)R;W(@97AT<F%C=&EN9R!Z:7`@;65M
M8F5R('1O("(D9&5S=%]N86UE(ET["F-H;6]D*#`U-34L("1D97-T7VYA;64I
M(&EF("1>3R!E<2`B:'!U>"(["GT*?0I]"GT*=6YL97-S("@D4$%2.CI,:6)#
M86-H97LD<')O9VYA;65]*2!["F1I92`\/"`B+B(@=6YL97-S($!!4D=6.PI5
M<V%G93H@)#`@6R`M06QI8BYP87(@72!;("U)9&ER(%T@6R`M36UO9'5L92!=
M(%L@<W)C+G!A<B!=(%L@<')O9W)A;2YP;"!="B0P(%L@+4)\+6(@72!;+4]O
M=71F:6QE72!S<F,N<&%R"BX*)$5.5GM005)?4%)/1TY!345](#T@)'!R;V=N
M86UE(#T@)#`@/2!S:&EF="A`05)'5BD["GT*<W5B($-R96%T95!A=&@@>PIM
M>2`H)&YA;64I(#T@0%\["G)E<75I<F4@1FEL93HZ0F%S96YA;64["FUY("@D
M8F%S96YA;64L("1P871H+"`D97AT*2`]($9I;&4Z.D)A<V5N86UE.CIF:6QE
M<&%R<V4H)&YA;64L("@G7"XN*B<I*3L*<F5Q=6ER92!&:6QE.CI0871H.PI&
M:6QE.CI0871H.CIM:W!A=&@H)'!A=&@I('5N;&5S<R@M92`D<&%T:"D[(",@
M;6MP871H(&1I97,@=VET:"!E<G)O<@I]"G-U8B!R97%U:7)E7VUO9'5L97,@
M>PIR97%U:7)E(&QI8CL*<F5Q=6ER92!$>6YA3&]A9&5R.PIR97%U:7)E(&EN
M=&5G97(["G)E<75I<F4@<W1R:6-T.PIR97%U:7)E('=A<FYI;F=S.PIR97%U
M:7)E('9A<G,["G)E<75I<F4@0V%R<#L*<F5Q=6ER92!#87)P.CI(96%V>3L*
M<F5Q=6ER92!%<G)N;SL*<F5Q=6ER92!%>'!O<G1E<CHZ2&5A=GD["G)E<75I
M<F4@17AP;W)T97(["G)E<75I<F4@1F-N=&P["G)E<75I<F4@1FEL93HZ5&5M
M<#L*<F5Q=6ER92!&:6QE.CI3<&5C.PIR97%U:7)E(%A33&]A9&5R.PIR97%U
M:7)E($-O;F9I9SL*<F5Q=6ER92!)3SHZ2&%N9&QE.PIR97%U:7)E($E/.CI&
M:6QE.PIR97%U:7)E($-O;7!R97-S.CI:;&EB.PIR97%U:7)E($%R8VAI=F4Z
M.EII<#L*<F5Q=6ER92!$:6=E<W0Z.E-(03L*<F5Q=6ER92!005(["G)E<75I
M<F4@4$%2.CI(96%V>3L*<F5Q=6ER92!005(Z.D1I<W0["G)E<75I<F4@4$%2
M.CI&:6QT97(Z.E!O9%-T<FEP.PIR97%U:7)E(%!!4CHZ1FEL=&5R.CI0871C
M:$-O;G1E;G0["G)E<75I<F4@871T<FEB=71E<SL*979A;"![(')E<75I<F4@
M0W=D('T["F5V86P@>R!R97%U:7)E(%=I;C,R('T["F5V86P@>R!R97%U:7)E
M(%-C86QA<CHZ571I;"!].PIE=F%L('L@<F5Q=6ER92!!<F-H:79E.CI5;GII
M<#HZ0G5R<W0@?3L*979A;"![(')E<75I<F4@5&EE.CI(87-H.CI.86UE9$-A
M<'1U<F4@?3L*979A;"![(')E<75I<F4@4&5R;$E/.R!R97%U:7)E(%!E<FQ)
M3SHZ<V-A;&%R('T["F5V86P@>R!R97%U:7)E('5T9C@@?3L*?0IS=6(@7W-E
M=%]P87)?=&5M<"!["FEF("AD969I;F5D("1%3E9[4$%27U1%35!](&%N9"`D
M14Y6>U!!4E]414U0?2`]?B`O*"XK*2\I('L*)'!A<E]T96UP(#T@)#$["G)E
M='5R;CL*?0IF;W)E86-H(&UY("1P871H("@**&UA<"`D14Y6>R1??2P@<7<H
M(%!!4E]435!$25(@5$U01$E2(%1%35!$25(@5$5-4"!435`@*2DL"G%W*"!#
M.EQ<5$5-4"`O=&UP("X@*0HI('L*;F5X="!U;FQE<W,@9&5F:6YE9"`D<&%T
M:"!A;F0@+60@)'!A=&@@86YD("UW("1P871H.PIM>2`D=7-E<FYA;64["FUY
M("1P=W5I9#L*979A;"![*"1P=W5I9"D@/2!G971P=W5I9"@D/BD@:68@9&5F
M:6YE9"`D/CM].PII9B`H(&1E9FEN960H)E=I;C,R.CI,;V=I;DYA;64I("D@
M>PHD=7-E<FYA;64@/2`F5VEN,S(Z.DQO9VEN3F%M93L*?0IE;'-I9B`H9&5F
M:6YE9"`D<'=U:60I('L*)'5S97)N86UE(#T@)'!W=6ED.PI]"F5L<V4@>PHD
M=7-E<FYA;64@/2`D14Y6>U5315).04U%?2!\?"`D14Y6>U5315)]('Q\("=3
M65-414TG.PI]"FUY("1S=&UP9&ER(#T@(B1P871H)'-Y<WM?9&5L:6U]<&%R
M+2(N=6YP86-K*")(*B(L("1U<V5R;F%M92D["FUK9&ER("1S=&UP9&ER+"`P
M-S4U.PIM>2`D8V%C:&5?9&ER.PII9B`H)$5.5GM005)?0TQ%04Y]*2!["B1C
M86-H95]D:7(@/2`B=&5M<"TD)"(["GT*96QS92!["F]P96X@;7D@)&9H+"`B
M/#IR87<B+"`D<')O9VYA;64@;W(@9&EE('%Q6T-A;B=T(')E860@(B1P<F]G
M;F%M92(Z("0A73L*:68@*"AM>2`D;6%G:6-?<&]S(#T@9FEN9%]P87)?;6%G
M:6,H)&9H*2D@/CT@,"D@>PIS965K("1F:"P@)&UA9VEC7W!O<PHM("1&24Q%
M7V]F9G-E=%]S:7IE"BT@;&5N9W1H*")<,$-!0TA%(BDL(#`["FUY("1B=68[
M"G)E860@)&9H+"`D8G5F+"!L96YG=&@H(EPP0T%#2$4B*3L*:68@*"1B=68@
M97$@(EPP0T%#2$4B*2!["G-E96L@)&9H+"`D;6%G:6-?<&]S"BT@)$9)3$5?
M;V9F<V5T7W-I>F4*+2!L96YG=&@H(EPP0T%#2$4B*0HM("1C86-H95]N86UE
M7W-I>F4L(#`["G)E860@)&9H+"`D8G5F+"`D8V%C:&5?;F%M95]S:7IE.PHD
M8G5F(#U^(',O7#`O+V<["B1C86-H95]D:7(@/2`B8V%C:&4M)&)U9B(["GT*
M?0IC;&]S92`D9F@["GT*:68@*"$D8V%C:&5?9&ER*2!["B1C86-H95]D:7(@
M/2`B=&5M<"TD)"(["B1%3E9[4$%27T-,14%.?2`](#$["GT*)'-T;7!D:7(@
M+CT@(B1S>7-[7V1E;&EM?21C86-H95]D:7(B.PIM:V1I<B`D<W1M<&1I<BP@
M,#<U-3L*)$5.5GM005)?5$5-4'T@/2`D<W1M<&1I<CL*;&%S=#L*?0HD<&%R
M7W1E;7`@/2`D,2!I9B`D14Y6>U!!4E]414U0?2!A;F0@)$5.5GM005)?5$5-
M4'T@/7X@+R@N*RDO.PI]"G-U8B!?<V%V95]A<R!["FUY("@D;F%M92P@)&-O
M;G1E;G1S+"`D;6]D92D@/2!`7SL*;7D@)&9U;&QN86UE(#T@(B1P87)?=&5M
M<"\D;F%M92(["G5N;&5S<R`H+64@)&9U;&QN86UE*2!["FUY("1T96UP;F%M
M92`]("(D9G5L;&YA;64N)"0B.PIM>2`D9F@["BAO<&5N("1F:"P@)SXZ<F%W
M)RP@)'1E;7!N86UE*0HF)B`H<')I;G0@)&9H("1C;VYT96YT<RD*)B8@*&-L
M;W-E("1F:"D*;W(@9&EE('%Q6T5R<F]R('=R:71I;F<@(B1T96UP;F%M92(Z
M("0A73L*8VAM;V0@)&UO9&4L("1T96UP;F%M92!I9B!D969I;F5D("1M;V1E
M.PIR96YA;64H)'1E;7!N86UE+"`D9G5L;&YA;64I(&]R('5N;&EN:R@D=&5M
M<&YA;64I.PI]"G)E='5R;B`D9G5L;&YA;64["GT*<W5B(%]S971?<')O9VYA
M;64@>PII9B`H9&5F:6YE9"`D14Y6>U!!4E]04D]'3D%-17T@86YD("1%3E9[
M4$%27U!23T=.04U%?2`]?B`O*"XK*2\I('L*)'!R;V=N86UE(#T@)#$["GT*
M)'!R;V=N86UE('Q\/2`D,#L*:68@*"1%3E9[4$%27U1%35!](&%N9"!I;F1E
M>"@D<')O9VYA;64L("1%3E9[4$%27U1%35!]*2`^/2`P*2!["B1P<F]G;F%M
M92`]('-U8G-T<B@D<')O9VYA;64L(')I;F1E>"@D<')O9VYA;64L("1S>7-[
M7V1E;&EM?2D@*R`Q*3L*?0II9B`H(21%3E9[4$%27U!23T=.04U%?2!O<B!I
M;F1E>"@D<')O9VYA;64L("1S>7-[7V1E;&EM?2D@/CT@,"D@>PII9B`H;W!E
M;B!M>2`D9F@L("<\)RP@)'!R;V=N86UE*2!["G)E='5R;B!I9B`M<R`D9F@[
M"GT*:68@*"US("(D<')O9VYA;64D<WES>U]E>&5](BD@>PHD<')O9VYA;64@
M+CT@)'-Y<WM?97AE?3L*<F5T=7)N.PI]"GT*9F]R96%C:"!M>2`D9&ER("AS
M<&QI="`O7%$D<WES>W!A=&A?<V5P?5Q%+RP@)$5.5GM0051(?2D@>PIN97AT
M(&EF(&5X:7-T<R`D14Y6>U!!4E]414U0?2!A;F0@)&1I<B!E<2`D14Y6>U!!
M4E]414U0?3L*)&1I<B`]?B!S+UQ1)'-Y<WM?9&5L:6U]7$4D+R\["B@H)'!R
M;V=N86UE(#T@(B1D:7(D<WES>U]D96QI;7TD<')O9VYA;64D<WES>U]E>&5]
M(BDL(&QA<W0I"FEF("US("(D9&ER)'-Y<WM?9&5L:6U])'!R;V=N86UE)'-Y
M<WM?97AE?2(["B@H)'!R;V=N86UE(#T@(B1D:7(D<WES>U]D96QI;7TD<')O
M9VYA;64B*2P@;&%S="D*:68@+7,@(B1D:7(D<WES>U]D96QI;7TD<')O9VYA
M;64B.PI]"GT*<W5B(%]F:7A?<')O9VYA;64@>PHD,"`]("1P<F]G;F%M92!\
M?#T@)$5.5GM005)?4%)/1TY!345].PII9B`H:6YD97@H)'!R;V=N86UE+"`D
M<WES>U]D96QI;7TI(#P@,"D@>PHD<')O9VYA;64@/2`B+B1S>7-[7V1E;&EM
M?21P<F]G;F%M92(["GT*;7D@)'!W9"`]("AD969I;F5D("9#=V0Z.F=E=&-W
M9"D@/R!#=V0Z.F=E=&-W9"@I"CH@*"AD969I;F5D("97:6XS,CHZ1V5T0W=D
M*2`_(%=I;C,R.CI'971#=V0H*2`Z(&!P=V1@*3L*8VAO;7`H)'!W9"D["B1P
M<F]G;F%M92`]?B!S+UXH/SU<+EPN/UQ1)'-Y<WM?9&5L:6U]7$4I+R1P=V0D
M<WES>U]D96QI;7TO.PHD14Y6>U!!4E]04D]'3D%-17T@/2`D<')O9VYA;64[
M"GT*<W5B(%]P87)?:6YI=%]E;G8@>PII9B`H("1%3E9[4$%27TE.251)04Q)
M6D5$?2LK(#T](#$@*2!["G)E='5R;CL*?2!E;'-E('L*)$5.5GM005)?24Y)
M5$E!3$E:141](#T@,CL*?0IF;W(@*'%W*"!34$%73D5$(%1%35`@0TQ%04X@
M1$5"54<@0T%#2$4@4%)/1TY!344@*2`I('L*9&5L971E("1%3E9[(E!!4E\D
M7R)].PI]"F9O<B`H<7<O(%1-4$1)4B!414U0($-,14%.($1%0E5'("\I('L*
M)$5.5GLB4$%27R1?(GT@/2`D14Y6>R)005)?1TQ/0D%,7R1?(GT@:68@97AI
M<W1S("1%3E9[(E!!4E]'3$]"04Q?)%\B?3L*?0II9B`H)$5.5GM005)?5$5-
M4'TI('L*9&5L971E("1%3E9[4$%27T-,14%.?3L*?0I]"G-U8B!O=71S('L*
M<F5T=7)N(&EF("1Q=6EE=#L*:68@*"1L;V=F:"D@>PIP<FEN="`D;&]G9F@@
M(D!?7&XB.PI]"F5L<V4@>PIP<FEN="`B0%]<;B(["GT*?0IS=6(@:6YI=%]I
M;F,@>PIR97%U:7)E($-O;F9I9SL*<'5S:"!`24Y#+"!G<F5P(&1E9FEN960L
M(&UA<"`D0V]N9FEG.CI#;VYF:6=[)%]]+"!Q=R@*87)C:&QI8F5X<"!P<FEV
M;&EB97AP('-I=&5A<F-H97AP('-I=&5L:6)E>'`*=F5N9&]R87)C:&5X<"!V
M96YD;W)L:6)E>'`**3L*?0IP86-K86=E(&UA:6X["G)E<75I<F4@4$%2.PIU
M;G-H:69T($!)3D,L(%PF4$%2.CIF:6YD7W!A<CL*4$%2+3YI;7!O<G0H0'!A
M<E]A<F=S*3L*9&EE('%Q6W!A<BYP;#H@0V%N)W0@;W!E;B!P97)L('-C<FEP
M="`B)'!R;V=N86UE(CH@3F\@<W5C:"!F:6QE(&]R(&1I<F5C=&]R>5QN70IU
M;FQE<W,@+64@)'!R;V=N86UE.PID;R`D<')O9VYA;64["D-/4D4Z.F5X:70H
M)#$I(&EF("@D0"`]?B]>7U1+7T58251?7"@H7&0K*5PI+RD["F1I92`D0"!I
M9B`D0#L*?3L*)#HZ7U]%4E)/4B`]("1`(&EF("1`.PI]"D-/4D4Z.F5X:70H
M)#$I(&EF("@D.CI?7T524D]2(#U^+UY?5$M?15A)5%]<*"A<9"LI7"DO*3L*
M9&EE("0Z.E]?15)23U(@:68@)#HZ7U]%4E)/4CL*,3L*7U]%3D1?7PH`<&5R
M;'AS:2YC`````$-!0TA%```]````0`````L```!`````$````$`````F````
M0````#4```!``````P```$`````&````0````!0```!`````#@```$`````-
M````0````"4```!`````$@```$`````H````0`````(```!`````&````$``
M```)````0`````H```!````````````````@C/]_`0``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````'P8```4&````0````H#```!````
M&@,```$````D`P``#````(`1```-````;$@``!D```#`_0$`&P````0````:
M````Q/T!`!P````$````]?[_;ZP!```%````!`D```8```"4`@``"@```)P$
M```+````$````!4``````````P```-#^`0`"````X`$``!0````1````%P``
M`*`/```1````T`X``!(```#0````$P````@````>````"````/O__V\!```(
M_O__;W`.``#___]O`@```/#__V^@#0``^O__;PX`````````````````````
M````````````````````````````````````R/T!````````````C!$``(P1
M``",$0``C!$``(P1``",$0``C!$``(P1``",$0``C!$``(P1``",$0``C!$`
M`(P1``",$0``C!$``(P1``",$0``C!$``(P1``",$0``C!$``(P1``",$0``
MC!$``(P1``",$0``C!$``(P1``",$0``C!$``(P1``",$0``C!$``(P1``",
M$0``C!$``(P1``",$0``C!$``(P1``",$0``C!$``(P1``",$0``C!$``(P1
M``",$0``C!$``(P1``",$0``C!$``(P1``",$0``C!$``(P1``",$0``C!$`
M`(P1``",$0``````````````````````````````````````````````````
M````````````````<!0````````$``(`"E!!4BYP;0H`````*$P``&1)````
M````)$H``"A*```<3```;$D``"1,````````"$P``!!,````````,$P``$=#
M0SH@*$1E8FEA;B`Q,BXR+C`M,3`I(#$R+C(N,`!!*@```&%E86)I``$@````
M!35410`&!`@!"0$2!!,!%`$5`1<#&`$9`1H"`"YS:'-T<G1A8@`N:6YT97)P
M`"YN;W1E+F=N=2YB=6EL9"UI9``N;F]T92Y!0DDM=&%G`"YG;G4N:&%S:``N
M9'EN<WEM`"YD>6YS='(`+F=N=2YV97)S:6]N`"YG;G4N=F5R<VEO;E]R`"YR
M96PN9'EN`"YR96PN<&QT`"YI;FET`"YT97AT`"YF:6YI`"YR;V1A=&$`+D%2
M32YE>&ED>``N96A?9G)A;64`+FEN:71?87)R87D`+F9I;FE?87)R87D`+F1Y
M;F%M:6,`+F=O=``N9&%T80`N8G-S`"YC;VUM96YT`"Y!4DTN871T<FEB=71E
M<P````````````````````````````````````````````````````````L`
M```!`````@```%0!``!4`0``$P```````````````0`````````3````!P``
M``(```!H`0``:`$``"0```````````````0`````````)@````<````"````
MC`$``(P!```@```````````````$`````````#0```#V__]O`@```*P!``"L
M`0``Z`````4`````````!`````0````^````"P````(```"4`@``E`(``'`&
M```&`````P````0````0````1@````,````"````!`D```0)``"<!```````
M```````!`````````$X```#___]O`@```*`-``"@#0``S@````4`````````
M`@````(```!;````_O__;P(```!P#@``<`X``&`````&`````@````0`````
M````:@````D````"````T`X``-`.``#0````!0`````````$````"````',`
M```)````0@```*`/``"@#P``X`$```4````5````!`````@```!\`````0``
M``8```"`$0``@!$```P```````````````0`````````=P````$````&````
MC!$``(P1``#D`@`````````````$````!````((````!````!@```'`4``!P
M%```_#,`````````````$`````````"(`````0````8```!L2```;$@```@`
M``````````````0`````````C@````$````"````=$@``'1(``"$0@``````
M```````$`````````)8````!``!P@@```/B*``#XB@``"`````T`````````
M!`````````"A`````0````(`````BP```(L```0```````````````0`````
M````JP````X````#````P/T!`,#]```$```````````````$````!````+<`
M```/`````P```,3]`0#$_0``!```````````````!`````0```##````!@``
M``,```#(_0$`R/T```@!```&``````````0````(````S`````$````#````
MT/X!`-#^```P`0`````````````$````!````-$````!`````P```````@``
M``$`2```````````````!`````````#7````"`````,```!(``(`2``!`!0`
M``````````````0`````````W`````$````P`````````$@``0`?````````
M```````!`````0```.4````#``!P``````````!G``$`*P``````````````
M`0`````````!`````P``````````````D@`!`/4```````````````$`````
#````
